# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = ['BgpIpArgs', 'BgpIp']

@pulumi.input_type
class BgpIpArgs:
    def __init__(__self__, *,
                 instance_id: pulumi.Input[str],
                 ip: pulumi.Input[str],
                 resource_group_id: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a BgpIp resource.
        :param pulumi.Input[str] instance_id: The ID of the native protection enterprise instance to be operated.
        :param pulumi.Input[str] ip: The IP address.
        :param pulumi.Input[str] resource_group_id: The ID of the resource group.
        """
        pulumi.set(__self__, "instance_id", instance_id)
        pulumi.set(__self__, "ip", ip)
        if resource_group_id is not None:
            pulumi.set(__self__, "resource_group_id", resource_group_id)

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> pulumi.Input[str]:
        """
        The ID of the native protection enterprise instance to be operated.
        """
        return pulumi.get(self, "instance_id")

    @instance_id.setter
    def instance_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "instance_id", value)

    @property
    @pulumi.getter
    def ip(self) -> pulumi.Input[str]:
        """
        The IP address.
        """
        return pulumi.get(self, "ip")

    @ip.setter
    def ip(self, value: pulumi.Input[str]):
        pulumi.set(self, "ip", value)

    @property
    @pulumi.getter(name="resourceGroupId")
    def resource_group_id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of the resource group.
        """
        return pulumi.get(self, "resource_group_id")

    @resource_group_id.setter
    def resource_group_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "resource_group_id", value)


@pulumi.input_type
class _BgpIpState:
    def __init__(__self__, *,
                 instance_id: Optional[pulumi.Input[str]] = None,
                 ip: Optional[pulumi.Input[str]] = None,
                 resource_group_id: Optional[pulumi.Input[str]] = None,
                 status: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering BgpIp resources.
        :param pulumi.Input[str] instance_id: The ID of the native protection enterprise instance to be operated.
        :param pulumi.Input[str] ip: The IP address.
        :param pulumi.Input[str] resource_group_id: The ID of the resource group.
        :param pulumi.Input[str] status: The current state of the IP address. Valid Value: `normal`, `hole_begin`.
        """
        if instance_id is not None:
            pulumi.set(__self__, "instance_id", instance_id)
        if ip is not None:
            pulumi.set(__self__, "ip", ip)
        if resource_group_id is not None:
            pulumi.set(__self__, "resource_group_id", resource_group_id)
        if status is not None:
            pulumi.set(__self__, "status", status)

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of the native protection enterprise instance to be operated.
        """
        return pulumi.get(self, "instance_id")

    @instance_id.setter
    def instance_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "instance_id", value)

    @property
    @pulumi.getter
    def ip(self) -> Optional[pulumi.Input[str]]:
        """
        The IP address.
        """
        return pulumi.get(self, "ip")

    @ip.setter
    def ip(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "ip", value)

    @property
    @pulumi.getter(name="resourceGroupId")
    def resource_group_id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of the resource group.
        """
        return pulumi.get(self, "resource_group_id")

    @resource_group_id.setter
    def resource_group_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "resource_group_id", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[str]]:
        """
        The current state of the IP address. Valid Value: `normal`, `hole_begin`.
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "status", value)


class BgpIp(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 instance_id: Optional[pulumi.Input[str]] = None,
                 ip: Optional[pulumi.Input[str]] = None,
                 resource_group_id: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Provides a Ddos Bgp Ip resource.

        For information about Ddos Bgp Ip and how to use it, see [What is Ip](https://www.alibabacloud.com/help/en/ddos-protection/latest/addip).

        > **NOTE:** Available in v1.180.0+.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        default_resource_groups = alicloud.resourcemanager.get_resource_groups()
        default_eip_address = alicloud.ecs.EipAddress("defaultEipAddress", address_name=var["name"])
        default_ddos_bgp_instances = alicloud.ddos.get_ddos_bgp_instances()
        default_bgp_ip = alicloud.ddos.BgpIp("defaultBgpIp",
            instance_id=default_ddos_bgp_instances.ids[0],
            ip=default_eip_address.ip_address,
            resource_group_id=default_resource_groups.groups[0].id)
        ```

        ## Import

        Ddos Bgp Ip can be imported using the id, e.g.

        ```sh
         $ pulumi import alicloud:ddos/bgpIp:BgpIp example <instance_id>:<ip>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] instance_id: The ID of the native protection enterprise instance to be operated.
        :param pulumi.Input[str] ip: The IP address.
        :param pulumi.Input[str] resource_group_id: The ID of the resource group.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: BgpIpArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a Ddos Bgp Ip resource.

        For information about Ddos Bgp Ip and how to use it, see [What is Ip](https://www.alibabacloud.com/help/en/ddos-protection/latest/addip).

        > **NOTE:** Available in v1.180.0+.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        default_resource_groups = alicloud.resourcemanager.get_resource_groups()
        default_eip_address = alicloud.ecs.EipAddress("defaultEipAddress", address_name=var["name"])
        default_ddos_bgp_instances = alicloud.ddos.get_ddos_bgp_instances()
        default_bgp_ip = alicloud.ddos.BgpIp("defaultBgpIp",
            instance_id=default_ddos_bgp_instances.ids[0],
            ip=default_eip_address.ip_address,
            resource_group_id=default_resource_groups.groups[0].id)
        ```

        ## Import

        Ddos Bgp Ip can be imported using the id, e.g.

        ```sh
         $ pulumi import alicloud:ddos/bgpIp:BgpIp example <instance_id>:<ip>
        ```

        :param str resource_name: The name of the resource.
        :param BgpIpArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(BgpIpArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 instance_id: Optional[pulumi.Input[str]] = None,
                 ip: Optional[pulumi.Input[str]] = None,
                 resource_group_id: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = BgpIpArgs.__new__(BgpIpArgs)

            if instance_id is None and not opts.urn:
                raise TypeError("Missing required property 'instance_id'")
            __props__.__dict__["instance_id"] = instance_id
            if ip is None and not opts.urn:
                raise TypeError("Missing required property 'ip'")
            __props__.__dict__["ip"] = ip
            __props__.__dict__["resource_group_id"] = resource_group_id
            __props__.__dict__["status"] = None
        super(BgpIp, __self__).__init__(
            'alicloud:ddos/bgpIp:BgpIp',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            instance_id: Optional[pulumi.Input[str]] = None,
            ip: Optional[pulumi.Input[str]] = None,
            resource_group_id: Optional[pulumi.Input[str]] = None,
            status: Optional[pulumi.Input[str]] = None) -> 'BgpIp':
        """
        Get an existing BgpIp resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] instance_id: The ID of the native protection enterprise instance to be operated.
        :param pulumi.Input[str] ip: The IP address.
        :param pulumi.Input[str] resource_group_id: The ID of the resource group.
        :param pulumi.Input[str] status: The current state of the IP address. Valid Value: `normal`, `hole_begin`.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _BgpIpState.__new__(_BgpIpState)

        __props__.__dict__["instance_id"] = instance_id
        __props__.__dict__["ip"] = ip
        __props__.__dict__["resource_group_id"] = resource_group_id
        __props__.__dict__["status"] = status
        return BgpIp(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> pulumi.Output[str]:
        """
        The ID of the native protection enterprise instance to be operated.
        """
        return pulumi.get(self, "instance_id")

    @property
    @pulumi.getter
    def ip(self) -> pulumi.Output[str]:
        """
        The IP address.
        """
        return pulumi.get(self, "ip")

    @property
    @pulumi.getter(name="resourceGroupId")
    def resource_group_id(self) -> pulumi.Output[Optional[str]]:
        """
        The ID of the resource group.
        """
        return pulumi.get(self, "resource_group_id")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[str]:
        """
        The current state of the IP address. Valid Value: `normal`, `hole_begin`.
        """
        return pulumi.get(self, "status")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs

__all__ = [
    'GetMonitorGroupInstancesResult',
    'AwaitableGetMonitorGroupInstancesResult',
    'get_monitor_group_instances',
    'get_monitor_group_instances_output',
]

@pulumi.output_type
class GetMonitorGroupInstancesResult:
    """
    A collection of values returned by getMonitorGroupInstances.
    """
    def __init__(__self__, id=None, ids=None, instances=None, keyword=None, output_file=None):
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if ids and not isinstance(ids, str):
            raise TypeError("Expected argument 'ids' to be a str")
        pulumi.set(__self__, "ids", ids)
        if instances and not isinstance(instances, list):
            raise TypeError("Expected argument 'instances' to be a list")
        pulumi.set(__self__, "instances", instances)
        if keyword and not isinstance(keyword, str):
            raise TypeError("Expected argument 'keyword' to be a str")
        pulumi.set(__self__, "keyword", keyword)
        if output_file and not isinstance(output_file, str):
            raise TypeError("Expected argument 'output_file' to be a str")
        pulumi.set(__self__, "output_file", output_file)

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def ids(self) -> str:
        return pulumi.get(self, "ids")

    @property
    @pulumi.getter
    def instances(self) -> Sequence['outputs.GetMonitorGroupInstancesInstanceResult']:
        return pulumi.get(self, "instances")

    @property
    @pulumi.getter
    def keyword(self) -> Optional[str]:
        return pulumi.get(self, "keyword")

    @property
    @pulumi.getter(name="outputFile")
    def output_file(self) -> Optional[str]:
        return pulumi.get(self, "output_file")


class AwaitableGetMonitorGroupInstancesResult(GetMonitorGroupInstancesResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetMonitorGroupInstancesResult(
            id=self.id,
            ids=self.ids,
            instances=self.instances,
            keyword=self.keyword,
            output_file=self.output_file)


def get_monitor_group_instances(ids: Optional[str] = None,
                                keyword: Optional[str] = None,
                                output_file: Optional[str] = None,
                                opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetMonitorGroupInstancesResult:
    """
    Use this data source to access information about an existing resource.
    """
    __args__ = dict()
    __args__['ids'] = ids
    __args__['keyword'] = keyword
    __args__['outputFile'] = output_file
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('alicloud:cms/getMonitorGroupInstances:getMonitorGroupInstances', __args__, opts=opts, typ=GetMonitorGroupInstancesResult).value

    return AwaitableGetMonitorGroupInstancesResult(
        id=pulumi.get(__ret__, 'id'),
        ids=pulumi.get(__ret__, 'ids'),
        instances=pulumi.get(__ret__, 'instances'),
        keyword=pulumi.get(__ret__, 'keyword'),
        output_file=pulumi.get(__ret__, 'output_file'))


@_utilities.lift_output_func(get_monitor_group_instances)
def get_monitor_group_instances_output(ids: Optional[pulumi.Input[str]] = None,
                                       keyword: Optional[pulumi.Input[Optional[str]]] = None,
                                       output_file: Optional[pulumi.Input[Optional[str]]] = None,
                                       opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetMonitorGroupInstancesResult]:
    """
    Use this data source to access information about an existing resource.
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = ['ConfigurationRecorderArgs', 'ConfigurationRecorder']

@pulumi.input_type
class ConfigurationRecorderArgs:
    def __init__(__self__, *,
                 enterprise_edition: Optional[pulumi.Input[bool]] = None,
                 resource_types: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None):
        """
        The set of arguments for constructing a ConfigurationRecorder resource.
        :param pulumi.Input[bool] enterprise_edition: Whether to use the enterprise version configuration audit. Valid values: `true` and `false`. Default value `false`. For enterprise accounts, We recommend you to use the resource alicloud_config_aggregator.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] resource_types: A list of resource types to be monitored. [Resource types that support Cloud Config.](https://www.alibabacloud.com/help/en/doc-detail/127411.htm)
               * If you use an ordinary account, the `resource_types` supports the update operation after the process of creation is completed.
               * If you use an enterprise account, the `resource_types` does not support updating.
        """
        if enterprise_edition is not None:
            pulumi.set(__self__, "enterprise_edition", enterprise_edition)
        if resource_types is not None:
            pulumi.set(__self__, "resource_types", resource_types)

    @property
    @pulumi.getter(name="enterpriseEdition")
    def enterprise_edition(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether to use the enterprise version configuration audit. Valid values: `true` and `false`. Default value `false`. For enterprise accounts, We recommend you to use the resource alicloud_config_aggregator.
        """
        return pulumi.get(self, "enterprise_edition")

    @enterprise_edition.setter
    def enterprise_edition(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "enterprise_edition", value)

    @property
    @pulumi.getter(name="resourceTypes")
    def resource_types(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        A list of resource types to be monitored. [Resource types that support Cloud Config.](https://www.alibabacloud.com/help/en/doc-detail/127411.htm)
        * If you use an ordinary account, the `resource_types` supports the update operation after the process of creation is completed.
        * If you use an enterprise account, the `resource_types` does not support updating.
        """
        return pulumi.get(self, "resource_types")

    @resource_types.setter
    def resource_types(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "resource_types", value)


@pulumi.input_type
class _ConfigurationRecorderState:
    def __init__(__self__, *,
                 enterprise_edition: Optional[pulumi.Input[bool]] = None,
                 organization_enable_status: Optional[pulumi.Input[str]] = None,
                 organization_master_id: Optional[pulumi.Input[int]] = None,
                 resource_types: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 status: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering ConfigurationRecorder resources.
        :param pulumi.Input[bool] enterprise_edition: Whether to use the enterprise version configuration audit. Valid values: `true` and `false`. Default value `false`. For enterprise accounts, We recommend you to use the resource alicloud_config_aggregator.
        :param pulumi.Input[str] organization_enable_status: Enterprise version configuration audit enabled status. Values: `REGISTRABLE`: Not enabled, `BUILDING`: Building and `REGISTERED`: Enabled.
        :param pulumi.Input[int] organization_master_id: The ID of the Enterprise management account.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] resource_types: A list of resource types to be monitored. [Resource types that support Cloud Config.](https://www.alibabacloud.com/help/en/doc-detail/127411.htm)
               * If you use an ordinary account, the `resource_types` supports the update operation after the process of creation is completed.
               * If you use an enterprise account, the `resource_types` does not support updating.
        :param pulumi.Input[str] status: Status of resource monitoring. Values: `REGISTRABLE`: Not registered, `BUILDING`: Under construction, `REGISTERED`: Registered and `REBUILDING`: Rebuilding.
        """
        if enterprise_edition is not None:
            pulumi.set(__self__, "enterprise_edition", enterprise_edition)
        if organization_enable_status is not None:
            pulumi.set(__self__, "organization_enable_status", organization_enable_status)
        if organization_master_id is not None:
            pulumi.set(__self__, "organization_master_id", organization_master_id)
        if resource_types is not None:
            pulumi.set(__self__, "resource_types", resource_types)
        if status is not None:
            pulumi.set(__self__, "status", status)

    @property
    @pulumi.getter(name="enterpriseEdition")
    def enterprise_edition(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether to use the enterprise version configuration audit. Valid values: `true` and `false`. Default value `false`. For enterprise accounts, We recommend you to use the resource alicloud_config_aggregator.
        """
        return pulumi.get(self, "enterprise_edition")

    @enterprise_edition.setter
    def enterprise_edition(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "enterprise_edition", value)

    @property
    @pulumi.getter(name="organizationEnableStatus")
    def organization_enable_status(self) -> Optional[pulumi.Input[str]]:
        """
        Enterprise version configuration audit enabled status. Values: `REGISTRABLE`: Not enabled, `BUILDING`: Building and `REGISTERED`: Enabled.
        """
        return pulumi.get(self, "organization_enable_status")

    @organization_enable_status.setter
    def organization_enable_status(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "organization_enable_status", value)

    @property
    @pulumi.getter(name="organizationMasterId")
    def organization_master_id(self) -> Optional[pulumi.Input[int]]:
        """
        The ID of the Enterprise management account.
        """
        return pulumi.get(self, "organization_master_id")

    @organization_master_id.setter
    def organization_master_id(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "organization_master_id", value)

    @property
    @pulumi.getter(name="resourceTypes")
    def resource_types(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        A list of resource types to be monitored. [Resource types that support Cloud Config.](https://www.alibabacloud.com/help/en/doc-detail/127411.htm)
        * If you use an ordinary account, the `resource_types` supports the update operation after the process of creation is completed.
        * If you use an enterprise account, the `resource_types` does not support updating.
        """
        return pulumi.get(self, "resource_types")

    @resource_types.setter
    def resource_types(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "resource_types", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[str]]:
        """
        Status of resource monitoring. Values: `REGISTRABLE`: Not registered, `BUILDING`: Under construction, `REGISTERED`: Registered and `REBUILDING`: Rebuilding.
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "status", value)


class ConfigurationRecorder(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 enterprise_edition: Optional[pulumi.Input[bool]] = None,
                 resource_types: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 __props__=None):
        """
        Provides a Alicloud Config Configuration Recorder resource. Cloud Config is a specialized service for evaluating resources. Cloud Config tracks configuration changes of your resources and evaluates configuration compliance. Cloud Config can help you evaluate numerous resources and maintain the continuous compliance of your cloud infrastructure.
        For information about Alicloud Config Configuration Recorder and how to use it, see [What is Configuration Recorder.](https://www.alibabacloud.com/help/en/cloud-config/latest/startconfigurationrecorder)

        > **NOTE:** Available since v1.99.0.

        > **NOTE:** The Cloud Config region only support `cn-shanghai` and `ap-southeast-1`.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        example = alicloud.cfg.ConfigurationRecorder("example", resource_types=[
            "ACS::ECS::Instance",
            "ACS::ECS::Disk",
        ])
        ```

        ## Import

        Alicloud Config Configuration Recorder can be imported using the id, e.g.

        ```sh
         $ pulumi import alicloud:cfg/configurationRecorder:ConfigurationRecorder example 122378463********
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[bool] enterprise_edition: Whether to use the enterprise version configuration audit. Valid values: `true` and `false`. Default value `false`. For enterprise accounts, We recommend you to use the resource alicloud_config_aggregator.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] resource_types: A list of resource types to be monitored. [Resource types that support Cloud Config.](https://www.alibabacloud.com/help/en/doc-detail/127411.htm)
               * If you use an ordinary account, the `resource_types` supports the update operation after the process of creation is completed.
               * If you use an enterprise account, the `resource_types` does not support updating.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: Optional[ConfigurationRecorderArgs] = None,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a Alicloud Config Configuration Recorder resource. Cloud Config is a specialized service for evaluating resources. Cloud Config tracks configuration changes of your resources and evaluates configuration compliance. Cloud Config can help you evaluate numerous resources and maintain the continuous compliance of your cloud infrastructure.
        For information about Alicloud Config Configuration Recorder and how to use it, see [What is Configuration Recorder.](https://www.alibabacloud.com/help/en/cloud-config/latest/startconfigurationrecorder)

        > **NOTE:** Available since v1.99.0.

        > **NOTE:** The Cloud Config region only support `cn-shanghai` and `ap-southeast-1`.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        example = alicloud.cfg.ConfigurationRecorder("example", resource_types=[
            "ACS::ECS::Instance",
            "ACS::ECS::Disk",
        ])
        ```

        ## Import

        Alicloud Config Configuration Recorder can be imported using the id, e.g.

        ```sh
         $ pulumi import alicloud:cfg/configurationRecorder:ConfigurationRecorder example 122378463********
        ```

        :param str resource_name: The name of the resource.
        :param ConfigurationRecorderArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ConfigurationRecorderArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 enterprise_edition: Optional[pulumi.Input[bool]] = None,
                 resource_types: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ConfigurationRecorderArgs.__new__(ConfigurationRecorderArgs)

            __props__.__dict__["enterprise_edition"] = enterprise_edition
            __props__.__dict__["resource_types"] = resource_types
            __props__.__dict__["organization_enable_status"] = None
            __props__.__dict__["organization_master_id"] = None
            __props__.__dict__["status"] = None
        super(ConfigurationRecorder, __self__).__init__(
            'alicloud:cfg/configurationRecorder:ConfigurationRecorder',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            enterprise_edition: Optional[pulumi.Input[bool]] = None,
            organization_enable_status: Optional[pulumi.Input[str]] = None,
            organization_master_id: Optional[pulumi.Input[int]] = None,
            resource_types: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
            status: Optional[pulumi.Input[str]] = None) -> 'ConfigurationRecorder':
        """
        Get an existing ConfigurationRecorder resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[bool] enterprise_edition: Whether to use the enterprise version configuration audit. Valid values: `true` and `false`. Default value `false`. For enterprise accounts, We recommend you to use the resource alicloud_config_aggregator.
        :param pulumi.Input[str] organization_enable_status: Enterprise version configuration audit enabled status. Values: `REGISTRABLE`: Not enabled, `BUILDING`: Building and `REGISTERED`: Enabled.
        :param pulumi.Input[int] organization_master_id: The ID of the Enterprise management account.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] resource_types: A list of resource types to be monitored. [Resource types that support Cloud Config.](https://www.alibabacloud.com/help/en/doc-detail/127411.htm)
               * If you use an ordinary account, the `resource_types` supports the update operation after the process of creation is completed.
               * If you use an enterprise account, the `resource_types` does not support updating.
        :param pulumi.Input[str] status: Status of resource monitoring. Values: `REGISTRABLE`: Not registered, `BUILDING`: Under construction, `REGISTERED`: Registered and `REBUILDING`: Rebuilding.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ConfigurationRecorderState.__new__(_ConfigurationRecorderState)

        __props__.__dict__["enterprise_edition"] = enterprise_edition
        __props__.__dict__["organization_enable_status"] = organization_enable_status
        __props__.__dict__["organization_master_id"] = organization_master_id
        __props__.__dict__["resource_types"] = resource_types
        __props__.__dict__["status"] = status
        return ConfigurationRecorder(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="enterpriseEdition")
    def enterprise_edition(self) -> pulumi.Output[bool]:
        """
        Whether to use the enterprise version configuration audit. Valid values: `true` and `false`. Default value `false`. For enterprise accounts, We recommend you to use the resource alicloud_config_aggregator.
        """
        return pulumi.get(self, "enterprise_edition")

    @property
    @pulumi.getter(name="organizationEnableStatus")
    def organization_enable_status(self) -> pulumi.Output[str]:
        """
        Enterprise version configuration audit enabled status. Values: `REGISTRABLE`: Not enabled, `BUILDING`: Building and `REGISTERED`: Enabled.
        """
        return pulumi.get(self, "organization_enable_status")

    @property
    @pulumi.getter(name="organizationMasterId")
    def organization_master_id(self) -> pulumi.Output[int]:
        """
        The ID of the Enterprise management account.
        """
        return pulumi.get(self, "organization_master_id")

    @property
    @pulumi.getter(name="resourceTypes")
    def resource_types(self) -> pulumi.Output[Sequence[str]]:
        """
        A list of resource types to be monitored. [Resource types that support Cloud Config.](https://www.alibabacloud.com/help/en/doc-detail/127411.htm)
        * If you use an ordinary account, the `resource_types` supports the update operation after the process of creation is completed.
        * If you use an enterprise account, the `resource_types` does not support updating.
        """
        return pulumi.get(self, "resource_types")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[str]:
        """
        Status of resource monitoring. Values: `REGISTRABLE`: Not registered, `BUILDING`: Under construction, `REGISTERED`: Registered and `REBUILDING`: Rebuilding.
        """
        return pulumi.get(self, "status")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = ['MailAddressArgs', 'MailAddress']

@pulumi.input_type
class MailAddressArgs:
    def __init__(__self__, *,
                 account_name: pulumi.Input[str],
                 sendtype: pulumi.Input[str],
                 password: Optional[pulumi.Input[str]] = None,
                 reply_address: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a MailAddress resource.
        :param pulumi.Input[str] account_name: The sender address. The email address must be filled in the format of account@domain, and only lowercase letters or numbers can be used.
        :param pulumi.Input[str] sendtype: Account type. Valid values: `batch`, `trigger`.
        :param pulumi.Input[str] password: Account password. The password must be length 10-20 string, contains numbers, uppercase letters, lowercase letters at the same time.
        :param pulumi.Input[str] reply_address: Return address.
        """
        pulumi.set(__self__, "account_name", account_name)
        pulumi.set(__self__, "sendtype", sendtype)
        if password is not None:
            pulumi.set(__self__, "password", password)
        if reply_address is not None:
            pulumi.set(__self__, "reply_address", reply_address)

    @property
    @pulumi.getter(name="accountName")
    def account_name(self) -> pulumi.Input[str]:
        """
        The sender address. The email address must be filled in the format of account@domain, and only lowercase letters or numbers can be used.
        """
        return pulumi.get(self, "account_name")

    @account_name.setter
    def account_name(self, value: pulumi.Input[str]):
        pulumi.set(self, "account_name", value)

    @property
    @pulumi.getter
    def sendtype(self) -> pulumi.Input[str]:
        """
        Account type. Valid values: `batch`, `trigger`.
        """
        return pulumi.get(self, "sendtype")

    @sendtype.setter
    def sendtype(self, value: pulumi.Input[str]):
        pulumi.set(self, "sendtype", value)

    @property
    @pulumi.getter
    def password(self) -> Optional[pulumi.Input[str]]:
        """
        Account password. The password must be length 10-20 string, contains numbers, uppercase letters, lowercase letters at the same time.
        """
        return pulumi.get(self, "password")

    @password.setter
    def password(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "password", value)

    @property
    @pulumi.getter(name="replyAddress")
    def reply_address(self) -> Optional[pulumi.Input[str]]:
        """
        Return address.
        """
        return pulumi.get(self, "reply_address")

    @reply_address.setter
    def reply_address(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "reply_address", value)


@pulumi.input_type
class _MailAddressState:
    def __init__(__self__, *,
                 account_name: Optional[pulumi.Input[str]] = None,
                 password: Optional[pulumi.Input[str]] = None,
                 reply_address: Optional[pulumi.Input[str]] = None,
                 sendtype: Optional[pulumi.Input[str]] = None,
                 status: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering MailAddress resources.
        :param pulumi.Input[str] account_name: The sender address. The email address must be filled in the format of account@domain, and only lowercase letters or numbers can be used.
        :param pulumi.Input[str] password: Account password. The password must be length 10-20 string, contains numbers, uppercase letters, lowercase letters at the same time.
        :param pulumi.Input[str] reply_address: Return address.
        :param pulumi.Input[str] sendtype: Account type. Valid values: `batch`, `trigger`.
        :param pulumi.Input[str] status: Account Status freeze: 1, normal: 0.
        """
        if account_name is not None:
            pulumi.set(__self__, "account_name", account_name)
        if password is not None:
            pulumi.set(__self__, "password", password)
        if reply_address is not None:
            pulumi.set(__self__, "reply_address", reply_address)
        if sendtype is not None:
            pulumi.set(__self__, "sendtype", sendtype)
        if status is not None:
            pulumi.set(__self__, "status", status)

    @property
    @pulumi.getter(name="accountName")
    def account_name(self) -> Optional[pulumi.Input[str]]:
        """
        The sender address. The email address must be filled in the format of account@domain, and only lowercase letters or numbers can be used.
        """
        return pulumi.get(self, "account_name")

    @account_name.setter
    def account_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "account_name", value)

    @property
    @pulumi.getter
    def password(self) -> Optional[pulumi.Input[str]]:
        """
        Account password. The password must be length 10-20 string, contains numbers, uppercase letters, lowercase letters at the same time.
        """
        return pulumi.get(self, "password")

    @password.setter
    def password(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "password", value)

    @property
    @pulumi.getter(name="replyAddress")
    def reply_address(self) -> Optional[pulumi.Input[str]]:
        """
        Return address.
        """
        return pulumi.get(self, "reply_address")

    @reply_address.setter
    def reply_address(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "reply_address", value)

    @property
    @pulumi.getter
    def sendtype(self) -> Optional[pulumi.Input[str]]:
        """
        Account type. Valid values: `batch`, `trigger`.
        """
        return pulumi.get(self, "sendtype")

    @sendtype.setter
    def sendtype(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "sendtype", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[str]]:
        """
        Account Status freeze: 1, normal: 0.
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "status", value)


class MailAddress(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 account_name: Optional[pulumi.Input[str]] = None,
                 password: Optional[pulumi.Input[str]] = None,
                 reply_address: Optional[pulumi.Input[str]] = None,
                 sendtype: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Provides a Direct Mail Mail Address resource.

        For information about Direct Mail Mail Address and how to use it, see [What is Mail Address](https://www.aliyun.com/product/directmail).

        > **NOTE:** Available in v1.134.0+.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        example = alicloud.directmail.MailAddress("example",
            account_name="example_value@email.com",
            sendtype="batch")
        ```

        > **Note:**
        A maximum of 10 mailing addresses can be added.
        Individual users: Up to 10 mailing addresses can be deleted within a month.
        Enterprise users: Up to 10 mailing addresses can be deleted within a month.

        ## Import

        Direct Mail Mail Address can be imported using the id, e.g.

        ```sh
         $ pulumi import alicloud:directmail/mailAddress:MailAddress example <id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] account_name: The sender address. The email address must be filled in the format of account@domain, and only lowercase letters or numbers can be used.
        :param pulumi.Input[str] password: Account password. The password must be length 10-20 string, contains numbers, uppercase letters, lowercase letters at the same time.
        :param pulumi.Input[str] reply_address: Return address.
        :param pulumi.Input[str] sendtype: Account type. Valid values: `batch`, `trigger`.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: MailAddressArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a Direct Mail Mail Address resource.

        For information about Direct Mail Mail Address and how to use it, see [What is Mail Address](https://www.aliyun.com/product/directmail).

        > **NOTE:** Available in v1.134.0+.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        example = alicloud.directmail.MailAddress("example",
            account_name="example_value@email.com",
            sendtype="batch")
        ```

        > **Note:**
        A maximum of 10 mailing addresses can be added.
        Individual users: Up to 10 mailing addresses can be deleted within a month.
        Enterprise users: Up to 10 mailing addresses can be deleted within a month.

        ## Import

        Direct Mail Mail Address can be imported using the id, e.g.

        ```sh
         $ pulumi import alicloud:directmail/mailAddress:MailAddress example <id>
        ```

        :param str resource_name: The name of the resource.
        :param MailAddressArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(MailAddressArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 account_name: Optional[pulumi.Input[str]] = None,
                 password: Optional[pulumi.Input[str]] = None,
                 reply_address: Optional[pulumi.Input[str]] = None,
                 sendtype: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = MailAddressArgs.__new__(MailAddressArgs)

            if account_name is None and not opts.urn:
                raise TypeError("Missing required property 'account_name'")
            __props__.__dict__["account_name"] = account_name
            __props__.__dict__["password"] = password
            __props__.__dict__["reply_address"] = reply_address
            if sendtype is None and not opts.urn:
                raise TypeError("Missing required property 'sendtype'")
            __props__.__dict__["sendtype"] = sendtype
            __props__.__dict__["status"] = None
        super(MailAddress, __self__).__init__(
            'alicloud:directmail/mailAddress:MailAddress',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            account_name: Optional[pulumi.Input[str]] = None,
            password: Optional[pulumi.Input[str]] = None,
            reply_address: Optional[pulumi.Input[str]] = None,
            sendtype: Optional[pulumi.Input[str]] = None,
            status: Optional[pulumi.Input[str]] = None) -> 'MailAddress':
        """
        Get an existing MailAddress resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] account_name: The sender address. The email address must be filled in the format of account@domain, and only lowercase letters or numbers can be used.
        :param pulumi.Input[str] password: Account password. The password must be length 10-20 string, contains numbers, uppercase letters, lowercase letters at the same time.
        :param pulumi.Input[str] reply_address: Return address.
        :param pulumi.Input[str] sendtype: Account type. Valid values: `batch`, `trigger`.
        :param pulumi.Input[str] status: Account Status freeze: 1, normal: 0.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _MailAddressState.__new__(_MailAddressState)

        __props__.__dict__["account_name"] = account_name
        __props__.__dict__["password"] = password
        __props__.__dict__["reply_address"] = reply_address
        __props__.__dict__["sendtype"] = sendtype
        __props__.__dict__["status"] = status
        return MailAddress(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="accountName")
    def account_name(self) -> pulumi.Output[str]:
        """
        The sender address. The email address must be filled in the format of account@domain, and only lowercase letters or numbers can be used.
        """
        return pulumi.get(self, "account_name")

    @property
    @pulumi.getter
    def password(self) -> pulumi.Output[Optional[str]]:
        """
        Account password. The password must be length 10-20 string, contains numbers, uppercase letters, lowercase letters at the same time.
        """
        return pulumi.get(self, "password")

    @property
    @pulumi.getter(name="replyAddress")
    def reply_address(self) -> pulumi.Output[Optional[str]]:
        """
        Return address.
        """
        return pulumi.get(self, "reply_address")

    @property
    @pulumi.getter
    def sendtype(self) -> pulumi.Output[str]:
        """
        Account type. Valid values: `batch`, `trigger`.
        """
        return pulumi.get(self, "sendtype")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[str]:
        """
        Account Status freeze: 1, normal: 0.
        """
        return pulumi.get(self, "status")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = ['EcsBackupPlanArgs', 'EcsBackupPlan']

@pulumi.input_type
class EcsBackupPlanArgs:
    def __init__(__self__, *,
                 backup_type: pulumi.Input[str],
                 ecs_backup_plan_name: pulumi.Input[str],
                 instance_id: pulumi.Input[str],
                 retention: pulumi.Input[str],
                 schedule: pulumi.Input[str],
                 vault_id: pulumi.Input[str],
                 cross_account_role_name: Optional[pulumi.Input[str]] = None,
                 cross_account_type: Optional[pulumi.Input[str]] = None,
                 cross_account_user_id: Optional[pulumi.Input[int]] = None,
                 detail: Optional[pulumi.Input[str]] = None,
                 disabled: Optional[pulumi.Input[bool]] = None,
                 exclude: Optional[pulumi.Input[str]] = None,
                 include: Optional[pulumi.Input[str]] = None,
                 options: Optional[pulumi.Input[str]] = None,
                 paths: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 speed_limit: Optional[pulumi.Input[str]] = None,
                 update_paths: Optional[pulumi.Input[bool]] = None):
        """
        The set of arguments for constructing a EcsBackupPlan resource.
        :param pulumi.Input[str] backup_type: Backup type. Valid values: `COMPLETE`.
        :param pulumi.Input[str] ecs_backup_plan_name: The name of the backup plan. 1~64 characters, the backup plan name of each data source type in a single warehouse required to be unique.
        :param pulumi.Input[str] instance_id: The ID of ECS instance. The ecs backup client must have been installed on the host.
        :param pulumi.Input[str] retention: Backup retention days, the minimum is 1.
        :param pulumi.Input[str] schedule: Backup strategy. Optional format: `I|{startTime}|{interval}`. It means to execute a backup task every `{interval}` starting from `{startTime}`. The backup task for the elapsed time will not be compensated. If the last backup task has not completed yet, the next backup task will not be triggered.
        :param pulumi.Input[str] vault_id: The ID of Backup vault.
        :param pulumi.Input[str] cross_account_role_name: The role name created in the original account RAM backup by the cross account managed by the current account.
        :param pulumi.Input[str] cross_account_type: The type of the cross account backup. Valid values: `SELF_ACCOUNT`, `CROSS_ACCOUNT`.
        :param pulumi.Input[int] cross_account_user_id: The original account ID of the cross account backup managed by the current account.
        :param pulumi.Input[str] detail: The detail of the backup plan.
        :param pulumi.Input[bool] disabled: Whether to disable the backup task. Valid values: `true`, `false`.
        :param pulumi.Input[str] exclude: Exclude path. String of Json list, up to 255 characters. e.g. `"[\\"/home/work\\"]"`
        :param pulumi.Input[str] include: Include path. String of Json list, up to 255 characters. e.g. `"[\\"/var\\"]"`
        :param pulumi.Input[str] options: Windows operating system with application consistency using VSS, e.g: `{\\"UseVSS\\":false}`.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] paths: List of backup path. e.g. `["/home", "/var"]`. **Note** If `path` is empty, it means that all directories will be backed up.
        :param pulumi.Input[str] speed_limit: Flow control. The format is: `{start}|{end}|{bandwidth}`. Use `|` to separate multiple flow control configurations, multiple flow control configurations not allowed to have overlapping times.
        :param pulumi.Input[bool] update_paths: Attribute update_paths has been deprecated in v1.139.0+, and you do not need to set it anymore.
        """
        pulumi.set(__self__, "backup_type", backup_type)
        pulumi.set(__self__, "ecs_backup_plan_name", ecs_backup_plan_name)
        pulumi.set(__self__, "instance_id", instance_id)
        pulumi.set(__self__, "retention", retention)
        pulumi.set(__self__, "schedule", schedule)
        pulumi.set(__self__, "vault_id", vault_id)
        if cross_account_role_name is not None:
            pulumi.set(__self__, "cross_account_role_name", cross_account_role_name)
        if cross_account_type is not None:
            pulumi.set(__self__, "cross_account_type", cross_account_type)
        if cross_account_user_id is not None:
            pulumi.set(__self__, "cross_account_user_id", cross_account_user_id)
        if detail is not None:
            pulumi.set(__self__, "detail", detail)
        if disabled is not None:
            pulumi.set(__self__, "disabled", disabled)
        if exclude is not None:
            pulumi.set(__self__, "exclude", exclude)
        if include is not None:
            pulumi.set(__self__, "include", include)
        if options is not None:
            pulumi.set(__self__, "options", options)
        if paths is not None:
            pulumi.set(__self__, "paths", paths)
        if speed_limit is not None:
            pulumi.set(__self__, "speed_limit", speed_limit)
        if update_paths is not None:
            warnings.warn("""Attribute update_paths has been deprecated in v1.139.0+ and you do not need to set it anymore.""", DeprecationWarning)
            pulumi.log.warn("""update_paths is deprecated: Attribute update_paths has been deprecated in v1.139.0+ and you do not need to set it anymore.""")
        if update_paths is not None:
            pulumi.set(__self__, "update_paths", update_paths)

    @property
    @pulumi.getter(name="backupType")
    def backup_type(self) -> pulumi.Input[str]:
        """
        Backup type. Valid values: `COMPLETE`.
        """
        return pulumi.get(self, "backup_type")

    @backup_type.setter
    def backup_type(self, value: pulumi.Input[str]):
        pulumi.set(self, "backup_type", value)

    @property
    @pulumi.getter(name="ecsBackupPlanName")
    def ecs_backup_plan_name(self) -> pulumi.Input[str]:
        """
        The name of the backup plan. 1~64 characters, the backup plan name of each data source type in a single warehouse required to be unique.
        """
        return pulumi.get(self, "ecs_backup_plan_name")

    @ecs_backup_plan_name.setter
    def ecs_backup_plan_name(self, value: pulumi.Input[str]):
        pulumi.set(self, "ecs_backup_plan_name", value)

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> pulumi.Input[str]:
        """
        The ID of ECS instance. The ecs backup client must have been installed on the host.
        """
        return pulumi.get(self, "instance_id")

    @instance_id.setter
    def instance_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "instance_id", value)

    @property
    @pulumi.getter
    def retention(self) -> pulumi.Input[str]:
        """
        Backup retention days, the minimum is 1.
        """
        return pulumi.get(self, "retention")

    @retention.setter
    def retention(self, value: pulumi.Input[str]):
        pulumi.set(self, "retention", value)

    @property
    @pulumi.getter
    def schedule(self) -> pulumi.Input[str]:
        """
        Backup strategy. Optional format: `I|{startTime}|{interval}`. It means to execute a backup task every `{interval}` starting from `{startTime}`. The backup task for the elapsed time will not be compensated. If the last backup task has not completed yet, the next backup task will not be triggered.
        """
        return pulumi.get(self, "schedule")

    @schedule.setter
    def schedule(self, value: pulumi.Input[str]):
        pulumi.set(self, "schedule", value)

    @property
    @pulumi.getter(name="vaultId")
    def vault_id(self) -> pulumi.Input[str]:
        """
        The ID of Backup vault.
        """
        return pulumi.get(self, "vault_id")

    @vault_id.setter
    def vault_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "vault_id", value)

    @property
    @pulumi.getter(name="crossAccountRoleName")
    def cross_account_role_name(self) -> Optional[pulumi.Input[str]]:
        """
        The role name created in the original account RAM backup by the cross account managed by the current account.
        """
        return pulumi.get(self, "cross_account_role_name")

    @cross_account_role_name.setter
    def cross_account_role_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "cross_account_role_name", value)

    @property
    @pulumi.getter(name="crossAccountType")
    def cross_account_type(self) -> Optional[pulumi.Input[str]]:
        """
        The type of the cross account backup. Valid values: `SELF_ACCOUNT`, `CROSS_ACCOUNT`.
        """
        return pulumi.get(self, "cross_account_type")

    @cross_account_type.setter
    def cross_account_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "cross_account_type", value)

    @property
    @pulumi.getter(name="crossAccountUserId")
    def cross_account_user_id(self) -> Optional[pulumi.Input[int]]:
        """
        The original account ID of the cross account backup managed by the current account.
        """
        return pulumi.get(self, "cross_account_user_id")

    @cross_account_user_id.setter
    def cross_account_user_id(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "cross_account_user_id", value)

    @property
    @pulumi.getter
    def detail(self) -> Optional[pulumi.Input[str]]:
        """
        The detail of the backup plan.
        """
        return pulumi.get(self, "detail")

    @detail.setter
    def detail(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "detail", value)

    @property
    @pulumi.getter
    def disabled(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether to disable the backup task. Valid values: `true`, `false`.
        """
        return pulumi.get(self, "disabled")

    @disabled.setter
    def disabled(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "disabled", value)

    @property
    @pulumi.getter
    def exclude(self) -> Optional[pulumi.Input[str]]:
        """
        Exclude path. String of Json list, up to 255 characters. e.g. `"[\\"/home/work\\"]"`
        """
        return pulumi.get(self, "exclude")

    @exclude.setter
    def exclude(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "exclude", value)

    @property
    @pulumi.getter
    def include(self) -> Optional[pulumi.Input[str]]:
        """
        Include path. String of Json list, up to 255 characters. e.g. `"[\\"/var\\"]"`
        """
        return pulumi.get(self, "include")

    @include.setter
    def include(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "include", value)

    @property
    @pulumi.getter
    def options(self) -> Optional[pulumi.Input[str]]:
        """
        Windows operating system with application consistency using VSS, e.g: `{\\"UseVSS\\":false}`.
        """
        return pulumi.get(self, "options")

    @options.setter
    def options(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "options", value)

    @property
    @pulumi.getter
    def paths(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        List of backup path. e.g. `["/home", "/var"]`. **Note** If `path` is empty, it means that all directories will be backed up.
        """
        return pulumi.get(self, "paths")

    @paths.setter
    def paths(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "paths", value)

    @property
    @pulumi.getter(name="speedLimit")
    def speed_limit(self) -> Optional[pulumi.Input[str]]:
        """
        Flow control. The format is: `{start}|{end}|{bandwidth}`. Use `|` to separate multiple flow control configurations, multiple flow control configurations not allowed to have overlapping times.
        """
        return pulumi.get(self, "speed_limit")

    @speed_limit.setter
    def speed_limit(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "speed_limit", value)

    @property
    @pulumi.getter(name="updatePaths")
    def update_paths(self) -> Optional[pulumi.Input[bool]]:
        """
        Attribute update_paths has been deprecated in v1.139.0+, and you do not need to set it anymore.
        """
        warnings.warn("""Attribute update_paths has been deprecated in v1.139.0+ and you do not need to set it anymore.""", DeprecationWarning)
        pulumi.log.warn("""update_paths is deprecated: Attribute update_paths has been deprecated in v1.139.0+ and you do not need to set it anymore.""")

        return pulumi.get(self, "update_paths")

    @update_paths.setter
    def update_paths(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "update_paths", value)


@pulumi.input_type
class _EcsBackupPlanState:
    def __init__(__self__, *,
                 backup_type: Optional[pulumi.Input[str]] = None,
                 cross_account_role_name: Optional[pulumi.Input[str]] = None,
                 cross_account_type: Optional[pulumi.Input[str]] = None,
                 cross_account_user_id: Optional[pulumi.Input[int]] = None,
                 detail: Optional[pulumi.Input[str]] = None,
                 disabled: Optional[pulumi.Input[bool]] = None,
                 ecs_backup_plan_name: Optional[pulumi.Input[str]] = None,
                 exclude: Optional[pulumi.Input[str]] = None,
                 include: Optional[pulumi.Input[str]] = None,
                 instance_id: Optional[pulumi.Input[str]] = None,
                 options: Optional[pulumi.Input[str]] = None,
                 paths: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 retention: Optional[pulumi.Input[str]] = None,
                 schedule: Optional[pulumi.Input[str]] = None,
                 speed_limit: Optional[pulumi.Input[str]] = None,
                 update_paths: Optional[pulumi.Input[bool]] = None,
                 vault_id: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering EcsBackupPlan resources.
        :param pulumi.Input[str] backup_type: Backup type. Valid values: `COMPLETE`.
        :param pulumi.Input[str] cross_account_role_name: The role name created in the original account RAM backup by the cross account managed by the current account.
        :param pulumi.Input[str] cross_account_type: The type of the cross account backup. Valid values: `SELF_ACCOUNT`, `CROSS_ACCOUNT`.
        :param pulumi.Input[int] cross_account_user_id: The original account ID of the cross account backup managed by the current account.
        :param pulumi.Input[str] detail: The detail of the backup plan.
        :param pulumi.Input[bool] disabled: Whether to disable the backup task. Valid values: `true`, `false`.
        :param pulumi.Input[str] ecs_backup_plan_name: The name of the backup plan. 1~64 characters, the backup plan name of each data source type in a single warehouse required to be unique.
        :param pulumi.Input[str] exclude: Exclude path. String of Json list, up to 255 characters. e.g. `"[\\"/home/work\\"]"`
        :param pulumi.Input[str] include: Include path. String of Json list, up to 255 characters. e.g. `"[\\"/var\\"]"`
        :param pulumi.Input[str] instance_id: The ID of ECS instance. The ecs backup client must have been installed on the host.
        :param pulumi.Input[str] options: Windows operating system with application consistency using VSS, e.g: `{\\"UseVSS\\":false}`.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] paths: List of backup path. e.g. `["/home", "/var"]`. **Note** If `path` is empty, it means that all directories will be backed up.
        :param pulumi.Input[str] retention: Backup retention days, the minimum is 1.
        :param pulumi.Input[str] schedule: Backup strategy. Optional format: `I|{startTime}|{interval}`. It means to execute a backup task every `{interval}` starting from `{startTime}`. The backup task for the elapsed time will not be compensated. If the last backup task has not completed yet, the next backup task will not be triggered.
        :param pulumi.Input[str] speed_limit: Flow control. The format is: `{start}|{end}|{bandwidth}`. Use `|` to separate multiple flow control configurations, multiple flow control configurations not allowed to have overlapping times.
        :param pulumi.Input[bool] update_paths: Attribute update_paths has been deprecated in v1.139.0+, and you do not need to set it anymore.
        :param pulumi.Input[str] vault_id: The ID of Backup vault.
        """
        if backup_type is not None:
            pulumi.set(__self__, "backup_type", backup_type)
        if cross_account_role_name is not None:
            pulumi.set(__self__, "cross_account_role_name", cross_account_role_name)
        if cross_account_type is not None:
            pulumi.set(__self__, "cross_account_type", cross_account_type)
        if cross_account_user_id is not None:
            pulumi.set(__self__, "cross_account_user_id", cross_account_user_id)
        if detail is not None:
            pulumi.set(__self__, "detail", detail)
        if disabled is not None:
            pulumi.set(__self__, "disabled", disabled)
        if ecs_backup_plan_name is not None:
            pulumi.set(__self__, "ecs_backup_plan_name", ecs_backup_plan_name)
        if exclude is not None:
            pulumi.set(__self__, "exclude", exclude)
        if include is not None:
            pulumi.set(__self__, "include", include)
        if instance_id is not None:
            pulumi.set(__self__, "instance_id", instance_id)
        if options is not None:
            pulumi.set(__self__, "options", options)
        if paths is not None:
            pulumi.set(__self__, "paths", paths)
        if retention is not None:
            pulumi.set(__self__, "retention", retention)
        if schedule is not None:
            pulumi.set(__self__, "schedule", schedule)
        if speed_limit is not None:
            pulumi.set(__self__, "speed_limit", speed_limit)
        if update_paths is not None:
            warnings.warn("""Attribute update_paths has been deprecated in v1.139.0+ and you do not need to set it anymore.""", DeprecationWarning)
            pulumi.log.warn("""update_paths is deprecated: Attribute update_paths has been deprecated in v1.139.0+ and you do not need to set it anymore.""")
        if update_paths is not None:
            pulumi.set(__self__, "update_paths", update_paths)
        if vault_id is not None:
            pulumi.set(__self__, "vault_id", vault_id)

    @property
    @pulumi.getter(name="backupType")
    def backup_type(self) -> Optional[pulumi.Input[str]]:
        """
        Backup type. Valid values: `COMPLETE`.
        """
        return pulumi.get(self, "backup_type")

    @backup_type.setter
    def backup_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "backup_type", value)

    @property
    @pulumi.getter(name="crossAccountRoleName")
    def cross_account_role_name(self) -> Optional[pulumi.Input[str]]:
        """
        The role name created in the original account RAM backup by the cross account managed by the current account.
        """
        return pulumi.get(self, "cross_account_role_name")

    @cross_account_role_name.setter
    def cross_account_role_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "cross_account_role_name", value)

    @property
    @pulumi.getter(name="crossAccountType")
    def cross_account_type(self) -> Optional[pulumi.Input[str]]:
        """
        The type of the cross account backup. Valid values: `SELF_ACCOUNT`, `CROSS_ACCOUNT`.
        """
        return pulumi.get(self, "cross_account_type")

    @cross_account_type.setter
    def cross_account_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "cross_account_type", value)

    @property
    @pulumi.getter(name="crossAccountUserId")
    def cross_account_user_id(self) -> Optional[pulumi.Input[int]]:
        """
        The original account ID of the cross account backup managed by the current account.
        """
        return pulumi.get(self, "cross_account_user_id")

    @cross_account_user_id.setter
    def cross_account_user_id(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "cross_account_user_id", value)

    @property
    @pulumi.getter
    def detail(self) -> Optional[pulumi.Input[str]]:
        """
        The detail of the backup plan.
        """
        return pulumi.get(self, "detail")

    @detail.setter
    def detail(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "detail", value)

    @property
    @pulumi.getter
    def disabled(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether to disable the backup task. Valid values: `true`, `false`.
        """
        return pulumi.get(self, "disabled")

    @disabled.setter
    def disabled(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "disabled", value)

    @property
    @pulumi.getter(name="ecsBackupPlanName")
    def ecs_backup_plan_name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the backup plan. 1~64 characters, the backup plan name of each data source type in a single warehouse required to be unique.
        """
        return pulumi.get(self, "ecs_backup_plan_name")

    @ecs_backup_plan_name.setter
    def ecs_backup_plan_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "ecs_backup_plan_name", value)

    @property
    @pulumi.getter
    def exclude(self) -> Optional[pulumi.Input[str]]:
        """
        Exclude path. String of Json list, up to 255 characters. e.g. `"[\\"/home/work\\"]"`
        """
        return pulumi.get(self, "exclude")

    @exclude.setter
    def exclude(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "exclude", value)

    @property
    @pulumi.getter
    def include(self) -> Optional[pulumi.Input[str]]:
        """
        Include path. String of Json list, up to 255 characters. e.g. `"[\\"/var\\"]"`
        """
        return pulumi.get(self, "include")

    @include.setter
    def include(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "include", value)

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of ECS instance. The ecs backup client must have been installed on the host.
        """
        return pulumi.get(self, "instance_id")

    @instance_id.setter
    def instance_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "instance_id", value)

    @property
    @pulumi.getter
    def options(self) -> Optional[pulumi.Input[str]]:
        """
        Windows operating system with application consistency using VSS, e.g: `{\\"UseVSS\\":false}`.
        """
        return pulumi.get(self, "options")

    @options.setter
    def options(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "options", value)

    @property
    @pulumi.getter
    def paths(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        List of backup path. e.g. `["/home", "/var"]`. **Note** If `path` is empty, it means that all directories will be backed up.
        """
        return pulumi.get(self, "paths")

    @paths.setter
    def paths(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "paths", value)

    @property
    @pulumi.getter
    def retention(self) -> Optional[pulumi.Input[str]]:
        """
        Backup retention days, the minimum is 1.
        """
        return pulumi.get(self, "retention")

    @retention.setter
    def retention(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "retention", value)

    @property
    @pulumi.getter
    def schedule(self) -> Optional[pulumi.Input[str]]:
        """
        Backup strategy. Optional format: `I|{startTime}|{interval}`. It means to execute a backup task every `{interval}` starting from `{startTime}`. The backup task for the elapsed time will not be compensated. If the last backup task has not completed yet, the next backup task will not be triggered.
        """
        return pulumi.get(self, "schedule")

    @schedule.setter
    def schedule(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "schedule", value)

    @property
    @pulumi.getter(name="speedLimit")
    def speed_limit(self) -> Optional[pulumi.Input[str]]:
        """
        Flow control. The format is: `{start}|{end}|{bandwidth}`. Use `|` to separate multiple flow control configurations, multiple flow control configurations not allowed to have overlapping times.
        """
        return pulumi.get(self, "speed_limit")

    @speed_limit.setter
    def speed_limit(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "speed_limit", value)

    @property
    @pulumi.getter(name="updatePaths")
    def update_paths(self) -> Optional[pulumi.Input[bool]]:
        """
        Attribute update_paths has been deprecated in v1.139.0+, and you do not need to set it anymore.
        """
        warnings.warn("""Attribute update_paths has been deprecated in v1.139.0+ and you do not need to set it anymore.""", DeprecationWarning)
        pulumi.log.warn("""update_paths is deprecated: Attribute update_paths has been deprecated in v1.139.0+ and you do not need to set it anymore.""")

        return pulumi.get(self, "update_paths")

    @update_paths.setter
    def update_paths(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "update_paths", value)

    @property
    @pulumi.getter(name="vaultId")
    def vault_id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of Backup vault.
        """
        return pulumi.get(self, "vault_id")

    @vault_id.setter
    def vault_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "vault_id", value)


class EcsBackupPlan(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 backup_type: Optional[pulumi.Input[str]] = None,
                 cross_account_role_name: Optional[pulumi.Input[str]] = None,
                 cross_account_type: Optional[pulumi.Input[str]] = None,
                 cross_account_user_id: Optional[pulumi.Input[int]] = None,
                 detail: Optional[pulumi.Input[str]] = None,
                 disabled: Optional[pulumi.Input[bool]] = None,
                 ecs_backup_plan_name: Optional[pulumi.Input[str]] = None,
                 exclude: Optional[pulumi.Input[str]] = None,
                 include: Optional[pulumi.Input[str]] = None,
                 instance_id: Optional[pulumi.Input[str]] = None,
                 options: Optional[pulumi.Input[str]] = None,
                 paths: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 retention: Optional[pulumi.Input[str]] = None,
                 schedule: Optional[pulumi.Input[str]] = None,
                 speed_limit: Optional[pulumi.Input[str]] = None,
                 update_paths: Optional[pulumi.Input[bool]] = None,
                 vault_id: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Provides a HBR Ecs Backup Plan resource.

        For information about HBR Ecs Backup Plan and how to use it, see [What is Ecs Backup Plan](https://www.alibabacloud.com/help/doc-detail/186574.htm).

        > **NOTE:** Available in v1.132.0+.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        example_zones = alicloud.get_zones(available_resource_creation="Instance")
        example_instance_types = alicloud.ecs.get_instance_types(availability_zone=example_zones.zones[0].id,
            cpu_core_count=1,
            memory_size=2)
        example_images = alicloud.ecs.get_images(name_regex="^ubuntu_[0-9]+_[0-9]+_x64*",
            owners="system")
        example_network = alicloud.vpc.Network("exampleNetwork",
            vpc_name="terraform-example",
            cidr_block="172.17.3.0/24")
        example_switch = alicloud.vpc.Switch("exampleSwitch",
            vswitch_name="terraform-example",
            cidr_block="172.17.3.0/24",
            vpc_id=example_network.id,
            zone_id=example_zones.zones[0].id)
        example_security_group = alicloud.ecs.SecurityGroup("exampleSecurityGroup", vpc_id=example_network.id)
        example_instance = alicloud.ecs.Instance("exampleInstance",
            image_id=example_images.images[0].id,
            instance_type=example_instance_types.instance_types[0].id,
            availability_zone=example_zones.zones[0].id,
            security_groups=[example_security_group.id],
            instance_name="terraform-example",
            internet_charge_type="PayByBandwidth",
            vswitch_id=example_switch.id)
        example_vault = alicloud.hbr.Vault("exampleVault", vault_name="terraform-example")
        example_ecs_backup_plan = alicloud.hbr.EcsBackupPlan("exampleEcsBackupPlan",
            ecs_backup_plan_name="terraform-example",
            instance_id=example_instance.id,
            vault_id=example_vault.id,
            retention="1",
            schedule="I|1602673264|PT2H",
            backup_type="COMPLETE",
            speed_limit="0:24:5120",
            paths=[
                "/home",
                "/var",
            ],
            exclude="  [\\"/home/exclude\\"]\\n",
            include="  [\\"/home/include\\"]\\n")
        ```
        ## Notice

        **About Backup path rules:**
        1. If there is no wildcard `*`, you can enter 8 items of path.
        2. When using wildcard `*`, only one item of path can be input, and wildcards like `/*/*` are supported.
        3. Each item of path only supports absolute paths, for example starting with `/`, `\\`, `C:\\`, `D:\\`.

        **About Restrictions:**
        1. When using `VSS`: multiple paths, UNC paths, wildcards, and excluded files not supported.
        2. When using `UNC`: VSS not supported, wildcards not supported, and files to be excluded are not supported.

        **About include/exclude path rules:**
        1. Supports up to 8 paths, including paths using wildcards `*`.
        2. If the path does not contain `/`, then `*` matches multiple path names or file names, for example `*abc*` will match `/abc/`, `/d/eabcd/`, `/a/abc`; `*.txt` will match all files with an extension `.txt`.
        3. If the path contains `/`, each `*` only matches a single-level path or file name. For example, `/a/*/*/` share will match `/a/b/c/share`, but not `/a/d/share`.
        4. If the path ends with `/`, it means the folder matches. For example, `*tmp/` will match `/a/b/aaatmp/`, `/tmp/` and so on.
        5. The path separator takes Linux system `/` as an example, if it is Windows system, please replace it with `\\`.

        ## Import

        HBR Ecs Backup Plan can be imported using the id, e.g.

        ```sh
         $ pulumi import alicloud:hbr/ecsBackupPlan:EcsBackupPlan example <id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] backup_type: Backup type. Valid values: `COMPLETE`.
        :param pulumi.Input[str] cross_account_role_name: The role name created in the original account RAM backup by the cross account managed by the current account.
        :param pulumi.Input[str] cross_account_type: The type of the cross account backup. Valid values: `SELF_ACCOUNT`, `CROSS_ACCOUNT`.
        :param pulumi.Input[int] cross_account_user_id: The original account ID of the cross account backup managed by the current account.
        :param pulumi.Input[str] detail: The detail of the backup plan.
        :param pulumi.Input[bool] disabled: Whether to disable the backup task. Valid values: `true`, `false`.
        :param pulumi.Input[str] ecs_backup_plan_name: The name of the backup plan. 1~64 characters, the backup plan name of each data source type in a single warehouse required to be unique.
        :param pulumi.Input[str] exclude: Exclude path. String of Json list, up to 255 characters. e.g. `"[\\"/home/work\\"]"`
        :param pulumi.Input[str] include: Include path. String of Json list, up to 255 characters. e.g. `"[\\"/var\\"]"`
        :param pulumi.Input[str] instance_id: The ID of ECS instance. The ecs backup client must have been installed on the host.
        :param pulumi.Input[str] options: Windows operating system with application consistency using VSS, e.g: `{\\"UseVSS\\":false}`.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] paths: List of backup path. e.g. `["/home", "/var"]`. **Note** If `path` is empty, it means that all directories will be backed up.
        :param pulumi.Input[str] retention: Backup retention days, the minimum is 1.
        :param pulumi.Input[str] schedule: Backup strategy. Optional format: `I|{startTime}|{interval}`. It means to execute a backup task every `{interval}` starting from `{startTime}`. The backup task for the elapsed time will not be compensated. If the last backup task has not completed yet, the next backup task will not be triggered.
        :param pulumi.Input[str] speed_limit: Flow control. The format is: `{start}|{end}|{bandwidth}`. Use `|` to separate multiple flow control configurations, multiple flow control configurations not allowed to have overlapping times.
        :param pulumi.Input[bool] update_paths: Attribute update_paths has been deprecated in v1.139.0+, and you do not need to set it anymore.
        :param pulumi.Input[str] vault_id: The ID of Backup vault.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: EcsBackupPlanArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a HBR Ecs Backup Plan resource.

        For information about HBR Ecs Backup Plan and how to use it, see [What is Ecs Backup Plan](https://www.alibabacloud.com/help/doc-detail/186574.htm).

        > **NOTE:** Available in v1.132.0+.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        example_zones = alicloud.get_zones(available_resource_creation="Instance")
        example_instance_types = alicloud.ecs.get_instance_types(availability_zone=example_zones.zones[0].id,
            cpu_core_count=1,
            memory_size=2)
        example_images = alicloud.ecs.get_images(name_regex="^ubuntu_[0-9]+_[0-9]+_x64*",
            owners="system")
        example_network = alicloud.vpc.Network("exampleNetwork",
            vpc_name="terraform-example",
            cidr_block="172.17.3.0/24")
        example_switch = alicloud.vpc.Switch("exampleSwitch",
            vswitch_name="terraform-example",
            cidr_block="172.17.3.0/24",
            vpc_id=example_network.id,
            zone_id=example_zones.zones[0].id)
        example_security_group = alicloud.ecs.SecurityGroup("exampleSecurityGroup", vpc_id=example_network.id)
        example_instance = alicloud.ecs.Instance("exampleInstance",
            image_id=example_images.images[0].id,
            instance_type=example_instance_types.instance_types[0].id,
            availability_zone=example_zones.zones[0].id,
            security_groups=[example_security_group.id],
            instance_name="terraform-example",
            internet_charge_type="PayByBandwidth",
            vswitch_id=example_switch.id)
        example_vault = alicloud.hbr.Vault("exampleVault", vault_name="terraform-example")
        example_ecs_backup_plan = alicloud.hbr.EcsBackupPlan("exampleEcsBackupPlan",
            ecs_backup_plan_name="terraform-example",
            instance_id=example_instance.id,
            vault_id=example_vault.id,
            retention="1",
            schedule="I|1602673264|PT2H",
            backup_type="COMPLETE",
            speed_limit="0:24:5120",
            paths=[
                "/home",
                "/var",
            ],
            exclude="  [\\"/home/exclude\\"]\\n",
            include="  [\\"/home/include\\"]\\n")
        ```
        ## Notice

        **About Backup path rules:**
        1. If there is no wildcard `*`, you can enter 8 items of path.
        2. When using wildcard `*`, only one item of path can be input, and wildcards like `/*/*` are supported.
        3. Each item of path only supports absolute paths, for example starting with `/`, `\\`, `C:\\`, `D:\\`.

        **About Restrictions:**
        1. When using `VSS`: multiple paths, UNC paths, wildcards, and excluded files not supported.
        2. When using `UNC`: VSS not supported, wildcards not supported, and files to be excluded are not supported.

        **About include/exclude path rules:**
        1. Supports up to 8 paths, including paths using wildcards `*`.
        2. If the path does not contain `/`, then `*` matches multiple path names or file names, for example `*abc*` will match `/abc/`, `/d/eabcd/`, `/a/abc`; `*.txt` will match all files with an extension `.txt`.
        3. If the path contains `/`, each `*` only matches a single-level path or file name. For example, `/a/*/*/` share will match `/a/b/c/share`, but not `/a/d/share`.
        4. If the path ends with `/`, it means the folder matches. For example, `*tmp/` will match `/a/b/aaatmp/`, `/tmp/` and so on.
        5. The path separator takes Linux system `/` as an example, if it is Windows system, please replace it with `\\`.

        ## Import

        HBR Ecs Backup Plan can be imported using the id, e.g.

        ```sh
         $ pulumi import alicloud:hbr/ecsBackupPlan:EcsBackupPlan example <id>
        ```

        :param str resource_name: The name of the resource.
        :param EcsBackupPlanArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(EcsBackupPlanArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 backup_type: Optional[pulumi.Input[str]] = None,
                 cross_account_role_name: Optional[pulumi.Input[str]] = None,
                 cross_account_type: Optional[pulumi.Input[str]] = None,
                 cross_account_user_id: Optional[pulumi.Input[int]] = None,
                 detail: Optional[pulumi.Input[str]] = None,
                 disabled: Optional[pulumi.Input[bool]] = None,
                 ecs_backup_plan_name: Optional[pulumi.Input[str]] = None,
                 exclude: Optional[pulumi.Input[str]] = None,
                 include: Optional[pulumi.Input[str]] = None,
                 instance_id: Optional[pulumi.Input[str]] = None,
                 options: Optional[pulumi.Input[str]] = None,
                 paths: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 retention: Optional[pulumi.Input[str]] = None,
                 schedule: Optional[pulumi.Input[str]] = None,
                 speed_limit: Optional[pulumi.Input[str]] = None,
                 update_paths: Optional[pulumi.Input[bool]] = None,
                 vault_id: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = EcsBackupPlanArgs.__new__(EcsBackupPlanArgs)

            if backup_type is None and not opts.urn:
                raise TypeError("Missing required property 'backup_type'")
            __props__.__dict__["backup_type"] = backup_type
            __props__.__dict__["cross_account_role_name"] = cross_account_role_name
            __props__.__dict__["cross_account_type"] = cross_account_type
            __props__.__dict__["cross_account_user_id"] = cross_account_user_id
            __props__.__dict__["detail"] = detail
            __props__.__dict__["disabled"] = disabled
            if ecs_backup_plan_name is None and not opts.urn:
                raise TypeError("Missing required property 'ecs_backup_plan_name'")
            __props__.__dict__["ecs_backup_plan_name"] = ecs_backup_plan_name
            __props__.__dict__["exclude"] = exclude
            __props__.__dict__["include"] = include
            if instance_id is None and not opts.urn:
                raise TypeError("Missing required property 'instance_id'")
            __props__.__dict__["instance_id"] = instance_id
            __props__.__dict__["options"] = options
            __props__.__dict__["paths"] = paths
            if retention is None and not opts.urn:
                raise TypeError("Missing required property 'retention'")
            __props__.__dict__["retention"] = retention
            if schedule is None and not opts.urn:
                raise TypeError("Missing required property 'schedule'")
            __props__.__dict__["schedule"] = schedule
            __props__.__dict__["speed_limit"] = speed_limit
            if update_paths is not None and not opts.urn:
                warnings.warn("""Attribute update_paths has been deprecated in v1.139.0+ and you do not need to set it anymore.""", DeprecationWarning)
                pulumi.log.warn("""update_paths is deprecated: Attribute update_paths has been deprecated in v1.139.0+ and you do not need to set it anymore.""")
            __props__.__dict__["update_paths"] = update_paths
            if vault_id is None and not opts.urn:
                raise TypeError("Missing required property 'vault_id'")
            __props__.__dict__["vault_id"] = vault_id
        super(EcsBackupPlan, __self__).__init__(
            'alicloud:hbr/ecsBackupPlan:EcsBackupPlan',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            backup_type: Optional[pulumi.Input[str]] = None,
            cross_account_role_name: Optional[pulumi.Input[str]] = None,
            cross_account_type: Optional[pulumi.Input[str]] = None,
            cross_account_user_id: Optional[pulumi.Input[int]] = None,
            detail: Optional[pulumi.Input[str]] = None,
            disabled: Optional[pulumi.Input[bool]] = None,
            ecs_backup_plan_name: Optional[pulumi.Input[str]] = None,
            exclude: Optional[pulumi.Input[str]] = None,
            include: Optional[pulumi.Input[str]] = None,
            instance_id: Optional[pulumi.Input[str]] = None,
            options: Optional[pulumi.Input[str]] = None,
            paths: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
            retention: Optional[pulumi.Input[str]] = None,
            schedule: Optional[pulumi.Input[str]] = None,
            speed_limit: Optional[pulumi.Input[str]] = None,
            update_paths: Optional[pulumi.Input[bool]] = None,
            vault_id: Optional[pulumi.Input[str]] = None) -> 'EcsBackupPlan':
        """
        Get an existing EcsBackupPlan resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] backup_type: Backup type. Valid values: `COMPLETE`.
        :param pulumi.Input[str] cross_account_role_name: The role name created in the original account RAM backup by the cross account managed by the current account.
        :param pulumi.Input[str] cross_account_type: The type of the cross account backup. Valid values: `SELF_ACCOUNT`, `CROSS_ACCOUNT`.
        :param pulumi.Input[int] cross_account_user_id: The original account ID of the cross account backup managed by the current account.
        :param pulumi.Input[str] detail: The detail of the backup plan.
        :param pulumi.Input[bool] disabled: Whether to disable the backup task. Valid values: `true`, `false`.
        :param pulumi.Input[str] ecs_backup_plan_name: The name of the backup plan. 1~64 characters, the backup plan name of each data source type in a single warehouse required to be unique.
        :param pulumi.Input[str] exclude: Exclude path. String of Json list, up to 255 characters. e.g. `"[\\"/home/work\\"]"`
        :param pulumi.Input[str] include: Include path. String of Json list, up to 255 characters. e.g. `"[\\"/var\\"]"`
        :param pulumi.Input[str] instance_id: The ID of ECS instance. The ecs backup client must have been installed on the host.
        :param pulumi.Input[str] options: Windows operating system with application consistency using VSS, e.g: `{\\"UseVSS\\":false}`.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] paths: List of backup path. e.g. `["/home", "/var"]`. **Note** If `path` is empty, it means that all directories will be backed up.
        :param pulumi.Input[str] retention: Backup retention days, the minimum is 1.
        :param pulumi.Input[str] schedule: Backup strategy. Optional format: `I|{startTime}|{interval}`. It means to execute a backup task every `{interval}` starting from `{startTime}`. The backup task for the elapsed time will not be compensated. If the last backup task has not completed yet, the next backup task will not be triggered.
        :param pulumi.Input[str] speed_limit: Flow control. The format is: `{start}|{end}|{bandwidth}`. Use `|` to separate multiple flow control configurations, multiple flow control configurations not allowed to have overlapping times.
        :param pulumi.Input[bool] update_paths: Attribute update_paths has been deprecated in v1.139.0+, and you do not need to set it anymore.
        :param pulumi.Input[str] vault_id: The ID of Backup vault.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _EcsBackupPlanState.__new__(_EcsBackupPlanState)

        __props__.__dict__["backup_type"] = backup_type
        __props__.__dict__["cross_account_role_name"] = cross_account_role_name
        __props__.__dict__["cross_account_type"] = cross_account_type
        __props__.__dict__["cross_account_user_id"] = cross_account_user_id
        __props__.__dict__["detail"] = detail
        __props__.__dict__["disabled"] = disabled
        __props__.__dict__["ecs_backup_plan_name"] = ecs_backup_plan_name
        __props__.__dict__["exclude"] = exclude
        __props__.__dict__["include"] = include
        __props__.__dict__["instance_id"] = instance_id
        __props__.__dict__["options"] = options
        __props__.__dict__["paths"] = paths
        __props__.__dict__["retention"] = retention
        __props__.__dict__["schedule"] = schedule
        __props__.__dict__["speed_limit"] = speed_limit
        __props__.__dict__["update_paths"] = update_paths
        __props__.__dict__["vault_id"] = vault_id
        return EcsBackupPlan(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="backupType")
    def backup_type(self) -> pulumi.Output[str]:
        """
        Backup type. Valid values: `COMPLETE`.
        """
        return pulumi.get(self, "backup_type")

    @property
    @pulumi.getter(name="crossAccountRoleName")
    def cross_account_role_name(self) -> pulumi.Output[Optional[str]]:
        """
        The role name created in the original account RAM backup by the cross account managed by the current account.
        """
        return pulumi.get(self, "cross_account_role_name")

    @property
    @pulumi.getter(name="crossAccountType")
    def cross_account_type(self) -> pulumi.Output[str]:
        """
        The type of the cross account backup. Valid values: `SELF_ACCOUNT`, `CROSS_ACCOUNT`.
        """
        return pulumi.get(self, "cross_account_type")

    @property
    @pulumi.getter(name="crossAccountUserId")
    def cross_account_user_id(self) -> pulumi.Output[Optional[int]]:
        """
        The original account ID of the cross account backup managed by the current account.
        """
        return pulumi.get(self, "cross_account_user_id")

    @property
    @pulumi.getter
    def detail(self) -> pulumi.Output[Optional[str]]:
        """
        The detail of the backup plan.
        """
        return pulumi.get(self, "detail")

    @property
    @pulumi.getter
    def disabled(self) -> pulumi.Output[bool]:
        """
        Whether to disable the backup task. Valid values: `true`, `false`.
        """
        return pulumi.get(self, "disabled")

    @property
    @pulumi.getter(name="ecsBackupPlanName")
    def ecs_backup_plan_name(self) -> pulumi.Output[str]:
        """
        The name of the backup plan. 1~64 characters, the backup plan name of each data source type in a single warehouse required to be unique.
        """
        return pulumi.get(self, "ecs_backup_plan_name")

    @property
    @pulumi.getter
    def exclude(self) -> pulumi.Output[Optional[str]]:
        """
        Exclude path. String of Json list, up to 255 characters. e.g. `"[\\"/home/work\\"]"`
        """
        return pulumi.get(self, "exclude")

    @property
    @pulumi.getter
    def include(self) -> pulumi.Output[Optional[str]]:
        """
        Include path. String of Json list, up to 255 characters. e.g. `"[\\"/var\\"]"`
        """
        return pulumi.get(self, "include")

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> pulumi.Output[str]:
        """
        The ID of ECS instance. The ecs backup client must have been installed on the host.
        """
        return pulumi.get(self, "instance_id")

    @property
    @pulumi.getter
    def options(self) -> pulumi.Output[Optional[str]]:
        """
        Windows operating system with application consistency using VSS, e.g: `{\\"UseVSS\\":false}`.
        """
        return pulumi.get(self, "options")

    @property
    @pulumi.getter
    def paths(self) -> pulumi.Output[Optional[Sequence[str]]]:
        """
        List of backup path. e.g. `["/home", "/var"]`. **Note** If `path` is empty, it means that all directories will be backed up.
        """
        return pulumi.get(self, "paths")

    @property
    @pulumi.getter
    def retention(self) -> pulumi.Output[str]:
        """
        Backup retention days, the minimum is 1.
        """
        return pulumi.get(self, "retention")

    @property
    @pulumi.getter
    def schedule(self) -> pulumi.Output[str]:
        """
        Backup strategy. Optional format: `I|{startTime}|{interval}`. It means to execute a backup task every `{interval}` starting from `{startTime}`. The backup task for the elapsed time will not be compensated. If the last backup task has not completed yet, the next backup task will not be triggered.
        """
        return pulumi.get(self, "schedule")

    @property
    @pulumi.getter(name="speedLimit")
    def speed_limit(self) -> pulumi.Output[Optional[str]]:
        """
        Flow control. The format is: `{start}|{end}|{bandwidth}`. Use `|` to separate multiple flow control configurations, multiple flow control configurations not allowed to have overlapping times.
        """
        return pulumi.get(self, "speed_limit")

    @property
    @pulumi.getter(name="updatePaths")
    def update_paths(self) -> pulumi.Output[Optional[bool]]:
        """
        Attribute update_paths has been deprecated in v1.139.0+, and you do not need to set it anymore.
        """
        warnings.warn("""Attribute update_paths has been deprecated in v1.139.0+ and you do not need to set it anymore.""", DeprecationWarning)
        pulumi.log.warn("""update_paths is deprecated: Attribute update_paths has been deprecated in v1.139.0+ and you do not need to set it anymore.""")

        return pulumi.get(self, "update_paths")

    @property
    @pulumi.getter(name="vaultId")
    def vault_id(self) -> pulumi.Output[str]:
        """
        The ID of Backup vault.
        """
        return pulumi.get(self, "vault_id")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

from .. import _utilities
import typing
# Export this package's modules as members:
from .dedicated_host import *
from .dedicated_host_account import *
from .dedicated_host_group import *
from .get_dedicated_host_accounts import *
from .get_dedicated_host_groups import *
from .get_dedicated_hosts import *
from .get_host_ecs_level_infos import *
from .get_zones import *
from . import outputs



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = ['SmbAclAttachmentArgs', 'SmbAclAttachment']

@pulumi.input_type
class SmbAclAttachmentArgs:
    def __init__(__self__, *,
                 file_system_id: pulumi.Input[str],
                 keytab: pulumi.Input[str],
                 keytab_md5: pulumi.Input[str],
                 enable_anonymous_access: Optional[pulumi.Input[bool]] = None,
                 encrypt_data: Optional[pulumi.Input[bool]] = None,
                 home_dir_path: Optional[pulumi.Input[str]] = None,
                 reject_unencrypted_access: Optional[pulumi.Input[bool]] = None,
                 super_admin_sid: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a SmbAclAttachment resource.
        :param pulumi.Input[str] file_system_id: The ID of the file system.
        :param pulumi.Input[str] keytab: The string that is generated after the system encodes the keytab file by using Base64.
        :param pulumi.Input[str] keytab_md5: RThe string that is generated after the system encodes the keytab file by using MD5.
        :param pulumi.Input[bool] enable_anonymous_access: Specifies whether to allow anonymous access. Valid values:
               true: The file system allows anonymous access.
               false: The file system denies anonymous access. Default value: false.
        :param pulumi.Input[bool] encrypt_data: Specifies whether to enable encryption in transit. Valid values:
               true: enables encryption in transit.
               false: disables encryption in transit. Default value: false.
        :param pulumi.Input[str] home_dir_path: The home directory of each user. Each user-specific home directory must meet the following requirements:    
               Each segment starts with a forward slash (/) or a backslash (\\).
               Each segment does not contain the following special characters: <>":?*.
               Each segment is 0 to 255 characters in length.
               The total length is 0 to 32,767 characters.
               For example, if you create a user named A and the home directory is /home, the file system automatically creates a directory named /home/A when User A logs on to the file system. If the /home/A directory already exists, the file system does not create the directory.
        :param pulumi.Input[bool] reject_unencrypted_access: Specifies whether to deny access from non-encrypted clients. Valid values:
               true: The file system denies access from non-encrypted clients.
               false: The file system allows access from non-encrypted clients. Default value: false.
        :param pulumi.Input[str] super_admin_sid: The ID of a super admin. The ID must meet the following requirements:
               The ID starts with S and does not contain letters except S.
               The ID contains at least three hyphens (-) as delimiters.
               Example: S-1-5-22 and S-1-5-22-23.
        """
        pulumi.set(__self__, "file_system_id", file_system_id)
        pulumi.set(__self__, "keytab", keytab)
        pulumi.set(__self__, "keytab_md5", keytab_md5)
        if enable_anonymous_access is not None:
            pulumi.set(__self__, "enable_anonymous_access", enable_anonymous_access)
        if encrypt_data is not None:
            pulumi.set(__self__, "encrypt_data", encrypt_data)
        if home_dir_path is not None:
            pulumi.set(__self__, "home_dir_path", home_dir_path)
        if reject_unencrypted_access is not None:
            pulumi.set(__self__, "reject_unencrypted_access", reject_unencrypted_access)
        if super_admin_sid is not None:
            pulumi.set(__self__, "super_admin_sid", super_admin_sid)

    @property
    @pulumi.getter(name="fileSystemId")
    def file_system_id(self) -> pulumi.Input[str]:
        """
        The ID of the file system.
        """
        return pulumi.get(self, "file_system_id")

    @file_system_id.setter
    def file_system_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "file_system_id", value)

    @property
    @pulumi.getter
    def keytab(self) -> pulumi.Input[str]:
        """
        The string that is generated after the system encodes the keytab file by using Base64.
        """
        return pulumi.get(self, "keytab")

    @keytab.setter
    def keytab(self, value: pulumi.Input[str]):
        pulumi.set(self, "keytab", value)

    @property
    @pulumi.getter(name="keytabMd5")
    def keytab_md5(self) -> pulumi.Input[str]:
        """
        RThe string that is generated after the system encodes the keytab file by using MD5.
        """
        return pulumi.get(self, "keytab_md5")

    @keytab_md5.setter
    def keytab_md5(self, value: pulumi.Input[str]):
        pulumi.set(self, "keytab_md5", value)

    @property
    @pulumi.getter(name="enableAnonymousAccess")
    def enable_anonymous_access(self) -> Optional[pulumi.Input[bool]]:
        """
        Specifies whether to allow anonymous access. Valid values:
        true: The file system allows anonymous access.
        false: The file system denies anonymous access. Default value: false.
        """
        return pulumi.get(self, "enable_anonymous_access")

    @enable_anonymous_access.setter
    def enable_anonymous_access(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "enable_anonymous_access", value)

    @property
    @pulumi.getter(name="encryptData")
    def encrypt_data(self) -> Optional[pulumi.Input[bool]]:
        """
        Specifies whether to enable encryption in transit. Valid values:
        true: enables encryption in transit.
        false: disables encryption in transit. Default value: false.
        """
        return pulumi.get(self, "encrypt_data")

    @encrypt_data.setter
    def encrypt_data(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "encrypt_data", value)

    @property
    @pulumi.getter(name="homeDirPath")
    def home_dir_path(self) -> Optional[pulumi.Input[str]]:
        """
        The home directory of each user. Each user-specific home directory must meet the following requirements:    
        Each segment starts with a forward slash (/) or a backslash (\\).
        Each segment does not contain the following special characters: <>":?*.
        Each segment is 0 to 255 characters in length.
        The total length is 0 to 32,767 characters.
        For example, if you create a user named A and the home directory is /home, the file system automatically creates a directory named /home/A when User A logs on to the file system. If the /home/A directory already exists, the file system does not create the directory.
        """
        return pulumi.get(self, "home_dir_path")

    @home_dir_path.setter
    def home_dir_path(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "home_dir_path", value)

    @property
    @pulumi.getter(name="rejectUnencryptedAccess")
    def reject_unencrypted_access(self) -> Optional[pulumi.Input[bool]]:
        """
        Specifies whether to deny access from non-encrypted clients. Valid values:
        true: The file system denies access from non-encrypted clients.
        false: The file system allows access from non-encrypted clients. Default value: false.
        """
        return pulumi.get(self, "reject_unencrypted_access")

    @reject_unencrypted_access.setter
    def reject_unencrypted_access(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "reject_unencrypted_access", value)

    @property
    @pulumi.getter(name="superAdminSid")
    def super_admin_sid(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of a super admin. The ID must meet the following requirements:
        The ID starts with S and does not contain letters except S.
        The ID contains at least three hyphens (-) as delimiters.
        Example: S-1-5-22 and S-1-5-22-23.
        """
        return pulumi.get(self, "super_admin_sid")

    @super_admin_sid.setter
    def super_admin_sid(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "super_admin_sid", value)


@pulumi.input_type
class _SmbAclAttachmentState:
    def __init__(__self__, *,
                 auth_method: Optional[pulumi.Input[str]] = None,
                 enable_anonymous_access: Optional[pulumi.Input[bool]] = None,
                 enabled: Optional[pulumi.Input[str]] = None,
                 encrypt_data: Optional[pulumi.Input[bool]] = None,
                 file_system_id: Optional[pulumi.Input[str]] = None,
                 home_dir_path: Optional[pulumi.Input[str]] = None,
                 keytab: Optional[pulumi.Input[str]] = None,
                 keytab_md5: Optional[pulumi.Input[str]] = None,
                 reject_unencrypted_access: Optional[pulumi.Input[bool]] = None,
                 super_admin_sid: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering SmbAclAttachment resources.
        :param pulumi.Input[str] auth_method: The method that is used to authenticate network identities.
        :param pulumi.Input[bool] enable_anonymous_access: Specifies whether to allow anonymous access. Valid values:
               true: The file system allows anonymous access.
               false: The file system denies anonymous access. Default value: false.
        :param pulumi.Input[str] enabled: Specifies whether to enable the ACL feature.
               true: enables the ACL feature.
               false: disables the ACL feature.
        :param pulumi.Input[bool] encrypt_data: Specifies whether to enable encryption in transit. Valid values:
               true: enables encryption in transit.
               false: disables encryption in transit. Default value: false.
        :param pulumi.Input[str] file_system_id: The ID of the file system.
        :param pulumi.Input[str] home_dir_path: The home directory of each user. Each user-specific home directory must meet the following requirements:    
               Each segment starts with a forward slash (/) or a backslash (\\).
               Each segment does not contain the following special characters: <>":?*.
               Each segment is 0 to 255 characters in length.
               The total length is 0 to 32,767 characters.
               For example, if you create a user named A and the home directory is /home, the file system automatically creates a directory named /home/A when User A logs on to the file system. If the /home/A directory already exists, the file system does not create the directory.
        :param pulumi.Input[str] keytab: The string that is generated after the system encodes the keytab file by using Base64.
        :param pulumi.Input[str] keytab_md5: RThe string that is generated after the system encodes the keytab file by using MD5.
        :param pulumi.Input[bool] reject_unencrypted_access: Specifies whether to deny access from non-encrypted clients. Valid values:
               true: The file system denies access from non-encrypted clients.
               false: The file system allows access from non-encrypted clients. Default value: false.
        :param pulumi.Input[str] super_admin_sid: The ID of a super admin. The ID must meet the following requirements:
               The ID starts with S and does not contain letters except S.
               The ID contains at least three hyphens (-) as delimiters.
               Example: S-1-5-22 and S-1-5-22-23.
        """
        if auth_method is not None:
            pulumi.set(__self__, "auth_method", auth_method)
        if enable_anonymous_access is not None:
            pulumi.set(__self__, "enable_anonymous_access", enable_anonymous_access)
        if enabled is not None:
            pulumi.set(__self__, "enabled", enabled)
        if encrypt_data is not None:
            pulumi.set(__self__, "encrypt_data", encrypt_data)
        if file_system_id is not None:
            pulumi.set(__self__, "file_system_id", file_system_id)
        if home_dir_path is not None:
            pulumi.set(__self__, "home_dir_path", home_dir_path)
        if keytab is not None:
            pulumi.set(__self__, "keytab", keytab)
        if keytab_md5 is not None:
            pulumi.set(__self__, "keytab_md5", keytab_md5)
        if reject_unencrypted_access is not None:
            pulumi.set(__self__, "reject_unencrypted_access", reject_unencrypted_access)
        if super_admin_sid is not None:
            pulumi.set(__self__, "super_admin_sid", super_admin_sid)

    @property
    @pulumi.getter(name="authMethod")
    def auth_method(self) -> Optional[pulumi.Input[str]]:
        """
        The method that is used to authenticate network identities.
        """
        return pulumi.get(self, "auth_method")

    @auth_method.setter
    def auth_method(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "auth_method", value)

    @property
    @pulumi.getter(name="enableAnonymousAccess")
    def enable_anonymous_access(self) -> Optional[pulumi.Input[bool]]:
        """
        Specifies whether to allow anonymous access. Valid values:
        true: The file system allows anonymous access.
        false: The file system denies anonymous access. Default value: false.
        """
        return pulumi.get(self, "enable_anonymous_access")

    @enable_anonymous_access.setter
    def enable_anonymous_access(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "enable_anonymous_access", value)

    @property
    @pulumi.getter
    def enabled(self) -> Optional[pulumi.Input[str]]:
        """
        Specifies whether to enable the ACL feature.
        true: enables the ACL feature.
        false: disables the ACL feature.
        """
        return pulumi.get(self, "enabled")

    @enabled.setter
    def enabled(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "enabled", value)

    @property
    @pulumi.getter(name="encryptData")
    def encrypt_data(self) -> Optional[pulumi.Input[bool]]:
        """
        Specifies whether to enable encryption in transit. Valid values:
        true: enables encryption in transit.
        false: disables encryption in transit. Default value: false.
        """
        return pulumi.get(self, "encrypt_data")

    @encrypt_data.setter
    def encrypt_data(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "encrypt_data", value)

    @property
    @pulumi.getter(name="fileSystemId")
    def file_system_id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of the file system.
        """
        return pulumi.get(self, "file_system_id")

    @file_system_id.setter
    def file_system_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "file_system_id", value)

    @property
    @pulumi.getter(name="homeDirPath")
    def home_dir_path(self) -> Optional[pulumi.Input[str]]:
        """
        The home directory of each user. Each user-specific home directory must meet the following requirements:    
        Each segment starts with a forward slash (/) or a backslash (\\).
        Each segment does not contain the following special characters: <>":?*.
        Each segment is 0 to 255 characters in length.
        The total length is 0 to 32,767 characters.
        For example, if you create a user named A and the home directory is /home, the file system automatically creates a directory named /home/A when User A logs on to the file system. If the /home/A directory already exists, the file system does not create the directory.
        """
        return pulumi.get(self, "home_dir_path")

    @home_dir_path.setter
    def home_dir_path(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "home_dir_path", value)

    @property
    @pulumi.getter
    def keytab(self) -> Optional[pulumi.Input[str]]:
        """
        The string that is generated after the system encodes the keytab file by using Base64.
        """
        return pulumi.get(self, "keytab")

    @keytab.setter
    def keytab(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "keytab", value)

    @property
    @pulumi.getter(name="keytabMd5")
    def keytab_md5(self) -> Optional[pulumi.Input[str]]:
        """
        RThe string that is generated after the system encodes the keytab file by using MD5.
        """
        return pulumi.get(self, "keytab_md5")

    @keytab_md5.setter
    def keytab_md5(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "keytab_md5", value)

    @property
    @pulumi.getter(name="rejectUnencryptedAccess")
    def reject_unencrypted_access(self) -> Optional[pulumi.Input[bool]]:
        """
        Specifies whether to deny access from non-encrypted clients. Valid values:
        true: The file system denies access from non-encrypted clients.
        false: The file system allows access from non-encrypted clients. Default value: false.
        """
        return pulumi.get(self, "reject_unencrypted_access")

    @reject_unencrypted_access.setter
    def reject_unencrypted_access(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "reject_unencrypted_access", value)

    @property
    @pulumi.getter(name="superAdminSid")
    def super_admin_sid(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of a super admin. The ID must meet the following requirements:
        The ID starts with S and does not contain letters except S.
        The ID contains at least three hyphens (-) as delimiters.
        Example: S-1-5-22 and S-1-5-22-23.
        """
        return pulumi.get(self, "super_admin_sid")

    @super_admin_sid.setter
    def super_admin_sid(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "super_admin_sid", value)


class SmbAclAttachment(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 enable_anonymous_access: Optional[pulumi.Input[bool]] = None,
                 encrypt_data: Optional[pulumi.Input[bool]] = None,
                 file_system_id: Optional[pulumi.Input[str]] = None,
                 home_dir_path: Optional[pulumi.Input[str]] = None,
                 keytab: Optional[pulumi.Input[str]] = None,
                 keytab_md5: Optional[pulumi.Input[str]] = None,
                 reject_unencrypted_access: Optional[pulumi.Input[bool]] = None,
                 super_admin_sid: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Provides a Nas Smb Acl resource.

        Alibaba Cloud SMB protocol file storage service supports user authentication based on AD domain system and permission access control at the file system level. Connecting and accessing the SMB file system as a domain user can implement the requirements for access control at the file and directory level in the SMB protocol file system. The current Alibaba Cloud SMB protocol file storage service does not support multi-user file and directory-level permission access control, and only provides file system-level authentication and access based on the whitelist mechanism that supports cloud accounts and source IP permission groups control.
        > **NOTE:** Available in 1.186.0+.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        example_zones = alicloud.nas.get_zones(file_system_type="standard")
        example_file_system = alicloud.nas.FileSystem("exampleFileSystem",
            protocol_type="SMB",
            storage_type="Capacity",
            description="terraform-example",
            encrypt_type=0,
            file_system_type="standard",
            zone_id=example_zones.zones[0].zone_id)
        example_smb_acl_attachment = alicloud.nas.SmbAclAttachment("exampleSmbAclAttachment",
            file_system_id=example_file_system.id,
            keytab="BQIAAABHAAIADUFMSUFEVEVTVC5DT00ABGNpZnMAGXNtYnNlcnZlcjI0LmFsaWFkdGVzdC5jb20AAAABAAAAAAEAAQAIqIx6v7p11oUAAABHAAIADUFMSUFEVEVTVC5DT00ABGNpZnMAGXNtYnNlcnZlcjI0LmFsaWFkdGVzdC5jb20AAAABAAAAAAEAAwAIqIx6v7p11oUAAABPAAIADUFMSUFEVEVTVC5DT00ABGNpZnMAGXNtYnNlcnZlcjI0LmFsaWFkdGVzdC5jb20AAAABAAAAAAEAFwAQnQZWB3RAPHU7PMIJyBWePAAAAF8AAgANQUxJQURURVNULkNPTQAEY2lmcwAZc21ic2VydmVyMjQuYWxpYWR0ZXN0LmNvbQAAAAEAAAAAAQASACAGJ7F0s+bcBjf6jD5HlvlRLmPSOW+qDZe0Qk0lQcf8WwAAAE8AAgANQUxJQURURVNULkNPTQAEY2lmcwAZc21ic2VydmVyMjQuYWxpYWR0ZXN0LmNvbQAAAAEAAAAAAQARABDdFmanrSIatnDDhoOXYadj",
            keytab_md5="E3CCF7E2416DF04FA958AA4513EA29E8")
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[bool] enable_anonymous_access: Specifies whether to allow anonymous access. Valid values:
               true: The file system allows anonymous access.
               false: The file system denies anonymous access. Default value: false.
        :param pulumi.Input[bool] encrypt_data: Specifies whether to enable encryption in transit. Valid values:
               true: enables encryption in transit.
               false: disables encryption in transit. Default value: false.
        :param pulumi.Input[str] file_system_id: The ID of the file system.
        :param pulumi.Input[str] home_dir_path: The home directory of each user. Each user-specific home directory must meet the following requirements:    
               Each segment starts with a forward slash (/) or a backslash (\\).
               Each segment does not contain the following special characters: <>":?*.
               Each segment is 0 to 255 characters in length.
               The total length is 0 to 32,767 characters.
               For example, if you create a user named A and the home directory is /home, the file system automatically creates a directory named /home/A when User A logs on to the file system. If the /home/A directory already exists, the file system does not create the directory.
        :param pulumi.Input[str] keytab: The string that is generated after the system encodes the keytab file by using Base64.
        :param pulumi.Input[str] keytab_md5: RThe string that is generated after the system encodes the keytab file by using MD5.
        :param pulumi.Input[bool] reject_unencrypted_access: Specifies whether to deny access from non-encrypted clients. Valid values:
               true: The file system denies access from non-encrypted clients.
               false: The file system allows access from non-encrypted clients. Default value: false.
        :param pulumi.Input[str] super_admin_sid: The ID of a super admin. The ID must meet the following requirements:
               The ID starts with S and does not contain letters except S.
               The ID contains at least three hyphens (-) as delimiters.
               Example: S-1-5-22 and S-1-5-22-23.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: SmbAclAttachmentArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a Nas Smb Acl resource.

        Alibaba Cloud SMB protocol file storage service supports user authentication based on AD domain system and permission access control at the file system level. Connecting and accessing the SMB file system as a domain user can implement the requirements for access control at the file and directory level in the SMB protocol file system. The current Alibaba Cloud SMB protocol file storage service does not support multi-user file and directory-level permission access control, and only provides file system-level authentication and access based on the whitelist mechanism that supports cloud accounts and source IP permission groups control.
        > **NOTE:** Available in 1.186.0+.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        example_zones = alicloud.nas.get_zones(file_system_type="standard")
        example_file_system = alicloud.nas.FileSystem("exampleFileSystem",
            protocol_type="SMB",
            storage_type="Capacity",
            description="terraform-example",
            encrypt_type=0,
            file_system_type="standard",
            zone_id=example_zones.zones[0].zone_id)
        example_smb_acl_attachment = alicloud.nas.SmbAclAttachment("exampleSmbAclAttachment",
            file_system_id=example_file_system.id,
            keytab="BQIAAABHAAIADUFMSUFEVEVTVC5DT00ABGNpZnMAGXNtYnNlcnZlcjI0LmFsaWFkdGVzdC5jb20AAAABAAAAAAEAAQAIqIx6v7p11oUAAABHAAIADUFMSUFEVEVTVC5DT00ABGNpZnMAGXNtYnNlcnZlcjI0LmFsaWFkdGVzdC5jb20AAAABAAAAAAEAAwAIqIx6v7p11oUAAABPAAIADUFMSUFEVEVTVC5DT00ABGNpZnMAGXNtYnNlcnZlcjI0LmFsaWFkdGVzdC5jb20AAAABAAAAAAEAFwAQnQZWB3RAPHU7PMIJyBWePAAAAF8AAgANQUxJQURURVNULkNPTQAEY2lmcwAZc21ic2VydmVyMjQuYWxpYWR0ZXN0LmNvbQAAAAEAAAAAAQASACAGJ7F0s+bcBjf6jD5HlvlRLmPSOW+qDZe0Qk0lQcf8WwAAAE8AAgANQUxJQURURVNULkNPTQAEY2lmcwAZc21ic2VydmVyMjQuYWxpYWR0ZXN0LmNvbQAAAAEAAAAAAQARABDdFmanrSIatnDDhoOXYadj",
            keytab_md5="E3CCF7E2416DF04FA958AA4513EA29E8")
        ```

        :param str resource_name: The name of the resource.
        :param SmbAclAttachmentArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(SmbAclAttachmentArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 enable_anonymous_access: Optional[pulumi.Input[bool]] = None,
                 encrypt_data: Optional[pulumi.Input[bool]] = None,
                 file_system_id: Optional[pulumi.Input[str]] = None,
                 home_dir_path: Optional[pulumi.Input[str]] = None,
                 keytab: Optional[pulumi.Input[str]] = None,
                 keytab_md5: Optional[pulumi.Input[str]] = None,
                 reject_unencrypted_access: Optional[pulumi.Input[bool]] = None,
                 super_admin_sid: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = SmbAclAttachmentArgs.__new__(SmbAclAttachmentArgs)

            __props__.__dict__["enable_anonymous_access"] = enable_anonymous_access
            __props__.__dict__["encrypt_data"] = encrypt_data
            if file_system_id is None and not opts.urn:
                raise TypeError("Missing required property 'file_system_id'")
            __props__.__dict__["file_system_id"] = file_system_id
            __props__.__dict__["home_dir_path"] = home_dir_path
            if keytab is None and not opts.urn:
                raise TypeError("Missing required property 'keytab'")
            __props__.__dict__["keytab"] = keytab
            if keytab_md5 is None and not opts.urn:
                raise TypeError("Missing required property 'keytab_md5'")
            __props__.__dict__["keytab_md5"] = keytab_md5
            __props__.__dict__["reject_unencrypted_access"] = reject_unencrypted_access
            __props__.__dict__["super_admin_sid"] = super_admin_sid
            __props__.__dict__["auth_method"] = None
            __props__.__dict__["enabled"] = None
        super(SmbAclAttachment, __self__).__init__(
            'alicloud:nas/smbAclAttachment:SmbAclAttachment',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            auth_method: Optional[pulumi.Input[str]] = None,
            enable_anonymous_access: Optional[pulumi.Input[bool]] = None,
            enabled: Optional[pulumi.Input[str]] = None,
            encrypt_data: Optional[pulumi.Input[bool]] = None,
            file_system_id: Optional[pulumi.Input[str]] = None,
            home_dir_path: Optional[pulumi.Input[str]] = None,
            keytab: Optional[pulumi.Input[str]] = None,
            keytab_md5: Optional[pulumi.Input[str]] = None,
            reject_unencrypted_access: Optional[pulumi.Input[bool]] = None,
            super_admin_sid: Optional[pulumi.Input[str]] = None) -> 'SmbAclAttachment':
        """
        Get an existing SmbAclAttachment resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] auth_method: The method that is used to authenticate network identities.
        :param pulumi.Input[bool] enable_anonymous_access: Specifies whether to allow anonymous access. Valid values:
               true: The file system allows anonymous access.
               false: The file system denies anonymous access. Default value: false.
        :param pulumi.Input[str] enabled: Specifies whether to enable the ACL feature.
               true: enables the ACL feature.
               false: disables the ACL feature.
        :param pulumi.Input[bool] encrypt_data: Specifies whether to enable encryption in transit. Valid values:
               true: enables encryption in transit.
               false: disables encryption in transit. Default value: false.
        :param pulumi.Input[str] file_system_id: The ID of the file system.
        :param pulumi.Input[str] home_dir_path: The home directory of each user. Each user-specific home directory must meet the following requirements:    
               Each segment starts with a forward slash (/) or a backslash (\\).
               Each segment does not contain the following special characters: <>":?*.
               Each segment is 0 to 255 characters in length.
               The total length is 0 to 32,767 characters.
               For example, if you create a user named A and the home directory is /home, the file system automatically creates a directory named /home/A when User A logs on to the file system. If the /home/A directory already exists, the file system does not create the directory.
        :param pulumi.Input[str] keytab: The string that is generated after the system encodes the keytab file by using Base64.
        :param pulumi.Input[str] keytab_md5: RThe string that is generated after the system encodes the keytab file by using MD5.
        :param pulumi.Input[bool] reject_unencrypted_access: Specifies whether to deny access from non-encrypted clients. Valid values:
               true: The file system denies access from non-encrypted clients.
               false: The file system allows access from non-encrypted clients. Default value: false.
        :param pulumi.Input[str] super_admin_sid: The ID of a super admin. The ID must meet the following requirements:
               The ID starts with S and does not contain letters except S.
               The ID contains at least three hyphens (-) as delimiters.
               Example: S-1-5-22 and S-1-5-22-23.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _SmbAclAttachmentState.__new__(_SmbAclAttachmentState)

        __props__.__dict__["auth_method"] = auth_method
        __props__.__dict__["enable_anonymous_access"] = enable_anonymous_access
        __props__.__dict__["enabled"] = enabled
        __props__.__dict__["encrypt_data"] = encrypt_data
        __props__.__dict__["file_system_id"] = file_system_id
        __props__.__dict__["home_dir_path"] = home_dir_path
        __props__.__dict__["keytab"] = keytab
        __props__.__dict__["keytab_md5"] = keytab_md5
        __props__.__dict__["reject_unencrypted_access"] = reject_unencrypted_access
        __props__.__dict__["super_admin_sid"] = super_admin_sid
        return SmbAclAttachment(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="authMethod")
    def auth_method(self) -> pulumi.Output[str]:
        """
        The method that is used to authenticate network identities.
        """
        return pulumi.get(self, "auth_method")

    @property
    @pulumi.getter(name="enableAnonymousAccess")
    def enable_anonymous_access(self) -> pulumi.Output[Optional[bool]]:
        """
        Specifies whether to allow anonymous access. Valid values:
        true: The file system allows anonymous access.
        false: The file system denies anonymous access. Default value: false.
        """
        return pulumi.get(self, "enable_anonymous_access")

    @property
    @pulumi.getter
    def enabled(self) -> pulumi.Output[str]:
        """
        Specifies whether to enable the ACL feature.
        true: enables the ACL feature.
        false: disables the ACL feature.
        """
        return pulumi.get(self, "enabled")

    @property
    @pulumi.getter(name="encryptData")
    def encrypt_data(self) -> pulumi.Output[Optional[bool]]:
        """
        Specifies whether to enable encryption in transit. Valid values:
        true: enables encryption in transit.
        false: disables encryption in transit. Default value: false.
        """
        return pulumi.get(self, "encrypt_data")

    @property
    @pulumi.getter(name="fileSystemId")
    def file_system_id(self) -> pulumi.Output[str]:
        """
        The ID of the file system.
        """
        return pulumi.get(self, "file_system_id")

    @property
    @pulumi.getter(name="homeDirPath")
    def home_dir_path(self) -> pulumi.Output[Optional[str]]:
        """
        The home directory of each user. Each user-specific home directory must meet the following requirements:    
        Each segment starts with a forward slash (/) or a backslash (\\).
        Each segment does not contain the following special characters: <>":?*.
        Each segment is 0 to 255 characters in length.
        The total length is 0 to 32,767 characters.
        For example, if you create a user named A and the home directory is /home, the file system automatically creates a directory named /home/A when User A logs on to the file system. If the /home/A directory already exists, the file system does not create the directory.
        """
        return pulumi.get(self, "home_dir_path")

    @property
    @pulumi.getter
    def keytab(self) -> pulumi.Output[str]:
        """
        The string that is generated after the system encodes the keytab file by using Base64.
        """
        return pulumi.get(self, "keytab")

    @property
    @pulumi.getter(name="keytabMd5")
    def keytab_md5(self) -> pulumi.Output[str]:
        """
        RThe string that is generated after the system encodes the keytab file by using MD5.
        """
        return pulumi.get(self, "keytab_md5")

    @property
    @pulumi.getter(name="rejectUnencryptedAccess")
    def reject_unencrypted_access(self) -> pulumi.Output[Optional[bool]]:
        """
        Specifies whether to deny access from non-encrypted clients. Valid values:
        true: The file system denies access from non-encrypted clients.
        false: The file system allows access from non-encrypted clients. Default value: false.
        """
        return pulumi.get(self, "reject_unencrypted_access")

    @property
    @pulumi.getter(name="superAdminSid")
    def super_admin_sid(self) -> pulumi.Output[Optional[str]]:
        """
        The ID of a super admin. The ID must meet the following requirements:
        The ID starts with S and does not contain letters except S.
        The ID contains at least three hyphens (-) as delimiters.
        Example: S-1-5-22 and S-1-5-22-23.
        """
        return pulumi.get(self, "super_admin_sid")

